@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Sep 15 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/
 
 /***************************************************************************
@@ -13,16 +13,15 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -156,7 +155,7 @@ BkNode & BkNode::operator=(const BkNode &node)
  *                                                                         *
  ***************************************************************************/
 
-void BkNode::attr(const char *name, QString &value, BRWSNUM browser) const
+void BkNode::attr(const QString &name, QString &value, BRWSNUM browser) const
 {
 	vector<BkAttr>::const_iterator it, start;
 
@@ -314,7 +313,7 @@ void BkNode::attr(int iAttr, QString &name, QString &value, BRWSNUM &browser) co
  *                                                                         *
  ***************************************************************************/
 
-void BkNode::setAttr(const char *name, const char *value, BRWSNUM browser)
+void BkNode::setAttr(const QString &name, const QString &value, BRWSNUM browser)
 {
 	BkAttr	temp;
 
