@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Sep 15 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/
 
 /***************************************************************************
@@ -13,23 +13,22 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef BKNODE_H
 #define BKNODE_H
 
-#include <qstring.h>
+#include <QString>
 #include <assert.h>
 
 #include <vector>
@@ -101,8 +100,6 @@ public:
 		return *this;
 	}
 
-	bool operator==(const char *str) const
-		{ return (m_name == str); }
 	bool operator==(const QString &str) const
 		{ return (m_name == str); }
 
@@ -184,7 +181,7 @@ public:
  ***************************************************************************/
 
 	void	attr(
-		const char *name, QString &value, BRWSNUM browser) const;
+		const QString &name, QString &value, BRWSNUM browser) const;
 	void	attr(
 		int iAttr, QString &name,
 		QString &value, BRWSNUM &browser) const
@@ -208,10 +205,10 @@ public:
  ***************************************************************************/
 
 	virtual bool operator==(const QString &str) const
-			{ return (m_title.lower() == str.lower()); }
+			{ return (m_title.toLower() == str.toLower()); }
 	virtual BkNode & operator=(const BkNode &node);
 	virtual bool operator<(const BkNode &node) const
-			{ return m_title.lower() < node.m_title.lower(); }
+			{ return m_title.toLower() < node.m_title.toLower(); }
 
 	virtual	BKNODET	type(void) const = 0;
 
@@ -258,7 +255,7 @@ public:
 	QString path(void) const
 			{ return m_path; }
 
-	void	setAttr(const char *name, const char *value, BRWSNUM browser);
+	void	setAttr(const QString &name, const QString &value, BRWSNUM browser);
 	void	setBrowserSaved(BRWSNUM browser)
 			{
 				if(std::find(
@@ -401,7 +398,7 @@ public:
 			{ return m_url; }
 
 	virtual bool operator==(const QString &str) const
-			{ return (m_url.lower() == str.lower()); }
+			{ return (m_url.toLower() == str.toLower()); }
 	virtual bool operator==(const BkBookmark &bmark) const;
 	virtual bool operator!=(const BkBookmark &bmark) const
 			{ return !operator==(bmark); }
@@ -414,7 +411,7 @@ public:
 			{ m_url = url; }
 
 	bool	findUrl(const QString &url) const
-			{ return url.lower() == m_url.lower(); }
+			{ return url.toLower() == m_url.toLower(); }
 
 	void	rollUpDifferences(void) throw(BkException);
 
