@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon Nov 18 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,40 +13,31 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #include "bridgecfg.h"
 #include "browserlist.h"
 
-#ifdef Q_WS_X11
-#include "config.h"
-#endif
-
 #include "xmlparser.h"
 #include "xbelwrite.h"
 #include "xbelread.h"
 
-#include <qdir.h>
-#include <qmessagebox.h>
-#include <iostream>
-#include <fstream>
+#include <QDir>
+#include <QMessageBox>
+#include <QApplication>
 
-#ifdef _WIN32
+#ifdef Q_WS_WIN
 #include <shlobj.h>
-#include <io.h>
-#else
-#include <unistd.h>
 #endif
 
 using namespace std;
@@ -232,7 +223,7 @@ static HKEY GetRegKey(HKEY Parent, const char *Path)
 	memcpy(key, Path, len);
 	key[len] = 0;
 
-	retval = RegOpenKeyEx(Parent, key, 0, KEY_READ, &hkey);
+	retval = RegOpenKeyExA(Parent, key, 0, KEY_READ, &hkey);
 	delete [] key;
 	if(retval != ERROR_SUCCESS)
 		return NULL;
@@ -248,58 +239,6 @@ static HKEY GetRegKey(HKEY Parent, const char *Path)
 }
 #endif
 
-/***************************************************************************
- *                                                                         *
- *   EncodeString()                                                        *
- *                                                                         *
- *   Parameters:                                                           *
- *      const char *str                                                    *
- *   Return:                                                               *
- *      encoded string                                                     *
- *   Description:                                                          *
- *      This function changes XML's special characters into XML entities.  *
- *                                                                         *
- ***************************************************************************/
-
-static string EncodeString(const char *str)
-{
-	int	len = strlen(str);
-
-	string outstr = "";
-	for(int i=0; i<len; i++)
-	{
-		switch(str[i])
-		{
-		case  '<':	outstr += "&lt;";	break;
-		case  '>':	outstr += "&gt;";	break;
-		case  '&':	outstr += "&amp;";	break;
-		case '\"':	outstr += "&quot;";	break;
-		case '\'':	outstr += "&apos;";	break;
-		default:	outstr += str[i];	break;
-		}
-	}
-
-	return outstr;
-}
-
-/***************************************************************************
- *                                                                         *
- *   EncodeString()                                                        *
- *                                                                         *
- *   Parameters:                                                           *
- *      const string &str                                                  *
- *   Return:                                                               *
- *      encoded string                                                     *
- *   Description:                                                          *
- *      Overloaded version of above function.                              *
- *                                                                         *
- ***************************************************************************/
-
-static string EncodeString(const string &str)
-{
-	return EncodeString(str.c_str());
-}
-
 /***************************************************************************
  *                                                                         *
  *   BridgeCfg::findConfigFile()   (X11 Version)                           *
@@ -321,7 +260,7 @@ void BridgeCfg::findConfigFile(void) throw(BkException)
 {
 	extern QString gConfigFile;
 	extern QString gTreeFile;
-	string	configPath;
+	QString	configPath;
 
 	configFileExists = false;
 	xbelFileExists = false;
@@ -330,50 +269,41 @@ void BridgeCfg::findConfigFile(void) throw(BkException)
 	{
 		// figure out where the configuration directory resides
 
-		configPath = string(static_cast<const char *>(QDir::homeDirPath())) + "/.bookmarkbridge";
-		QDir homeDir(QDir::homeDirPath());
+		QDir homeDir(QDir::homePath());
+        configPath = QDir::homePath() + "/.bookmarkbridge";
 
 		// create it if necessary
 
-		if( homeDir.exists(configPath.c_str()) == false
-		 && homeDir.mkdir(configPath.c_str()) == false)
-		{
-			QString msg;
-
-			msg.sprintf("Unable to Create Configuration Directory\n%s",
-				configPath.c_str());
-			BKEXCEPT(msg);
-		}
+		if( homeDir.exists(".bookmarkbridge") == false
+		 && homeDir.mkdir(".bookmarkbridge") == false)
+			BKEXCEPT("Unable to Create Configuration Directory");
 
 		// the configuration file
 
-		configFileName = configPath + "/bridgeconf.xml";
+		ConfigFileName = configPath + "/bridgeconf.xml";
 
-		QDir configDir(configPath.c_str());
+		QDir configDir(configPath);
 		configFileExists = configDir.exists("bridgeconf.xml");
 	}
 	else
 	{
-		configFileName = static_cast<const char *>(gConfigFile);
-		if(access(configFileName.c_str(), 0) == 0)
-			configFileExists = true;
+		ConfigFileName = gConfigFile;
+		configFileExists = QFile::exists(ConfigFileName);
 	}
 
 	// the bookmark tree file (XBEL)
 
 	if(gTreeFile == QString::null)
-		xbelFileName = configPath + "/bookmarks.xbel";
+		XbelFileName = configPath + "/bookmarks.xbel";
 	else
-		xbelFileName = static_cast<const char *>(gTreeFile);
-	if(access(xbelFileName.c_str(), 0) == 0)
-		xbelFileExists = true;
+		XbelFileName = gTreeFile;
+	xbelFileExists = QFile::exists(XbelFileName);
 
-	datadir = DATADIR;
+    DataDir = DATADIR;
 }
 #elif defined(Q_WS_WIN)
 void BridgeCfg::findConfigFile(void) throw(BkException)
 {
-	char	appdata[_MAX_PATH];
 	extern QString gConfigFile;
 	extern QString gTreeFile;
 
@@ -388,53 +318,39 @@ void BridgeCfg::findConfigFile(void) throw(BkException)
 
 		// figure out where the configuration directory resides
 
-		configPath.sprintf("%s\\BookmarkBridge", appdatadir.c_str());
-		QDir appdataDir(appdatadir.c_str());
+		configPath = m_AppDataDir + "\\BookmarkBridge";
+		QDir appdataDir(m_AppDataDir);
 
 		// create it if necessary
 
 		if( appdataDir.exists(configPath) == false
 		 && appdataDir.mkdir(configPath) == false)
-		{
-			QString msg;
-
-			msg.sprintf("Unable to Create Configuration Directory\n%s",
-				static_cast<const char *>(configPath));
-			BKEXCEPT(msg);
-		}
+			BKEXCEPT("Unable to Create Configuration Directory");
 
 		// the configuration file
 
-		configFileName = configPath + "/bridgeconf.xml";
+		ConfigFileName = configPath + "/bridgeconf.xml";
 
 		QDir configDir(configPath);
 		configFileExists = configDir.exists("bridgeconf.xml");
 	}
 	else
 	{
-		configFileName = gConfigFile;
-		if(access(configFileName.c_str(), 0) == 0)
-			configFileExists = true;
+		ConfigFileName = gConfigFile;
+		configFileExists = QFile::exists(ConfigFileName);
 	}
 
 	// the bookmark tree file (XBEL)
 
 	if(gTreeFile == QString::null)
-		xbelFileName = configPath + "/bookmarks.xbel";
+		XbelFileName = configPath + "/bookmarks.xbel";
 	else
-		xbelFileName = gTreeFile;
-	if(access(xbelFileName.c_str(), 0) == 0)
-		xbelFileExists = true;
+		XbelFileName = gTreeFile;
+	xbelFileExists = QFile::exists(XbelFileName);
 
 	// the data directory
 
-	if(GetModuleFileName(NULL, appdata, sizeof(appdata)) == 0)
-		BKEXCEPT("Unable to Determine Location of Data Files");
-	char *ch = strrchr(appdata, '\\');
-	if(ch == NULL)
-		BKEXCEPT("Malformed Path Name of Executable");
-	*ch = 0;
-	datadir = appdata;
+	DataDir = QApplication::applicationDirPath();
 }
 #else
 #error "Must Define Code to Find Config File"
@@ -522,13 +438,6 @@ void BridgeCfg::InitDefaults(void) throw(BkException)
 		delete browser;
 	}
 
-	QMessageBox::information(NULL, "Notice",
-		"BookmarkBridge has attempted to detect all browsers\n"
-		"on your system.  Any browsers it has detected were\n"
-		"automatically added as both a source and destination\n"
-		"for bookmark synchronization.  Please take the time\n"
-		"to click the Settings button and verify your configuration.");
-
 	writeConfig();
 }
 
@@ -551,65 +460,29 @@ void BridgeCfg::InitDefaults(void) throw(BkException)
 #ifdef Q_WS_WIN
 void BridgeCfg::InitMemberVars(void) throw(BkException)
 {
-	HINSTANCE	hShell32;
-	char		progdir[_MAX_PATH];
-	HKEY		winkey;
-	
-	winkey = GetRegKey(HKEY_LOCAL_MACHINE, "Software\\Microsoft\\Windows\\CurrentVersion");
-	if(winkey == NULL)
-		strcpy(progdir, "C:\\Program Files");
-	else
+	wchar_t widebuf[MAX_PATH];
+
+	memset(widebuf, 0, sizeof(widebuf));
+	if(SHGetFolderPathW(NULL, CSIDL_FAVORITES, NULL, 0, widebuf) != S_OK)
 	{
-		DWORD	datasize = sizeof(progdir);
-		DWORD	type;
-
-		if(	RegQueryValueEx(
-				winkey,
-				"ProgramFilesDir",
-				NULL,
-				&type,
-				(UCHAR *)progdir,
-				&datasize) != ERROR_SUCCESS
-		 ||	type != REG_SZ)
-			strcpy(progdir, "C:\\Program Files");
-
-		RegCloseKey(winkey);
-	}
-	progfilesdir = progdir;
-
-	if(hShell32 = LoadLibrary("SHELL32.DLL"))
-	{
-		char	appdata[_MAX_PATH];
-
-		typedef BOOL (CALLBACK* SHGetSpecialFolderPathAProc)(HWND, LPCSTR, int, BOOL);
-		SHGetSpecialFolderPathAProc SHgsfp = (SHGetSpecialFolderPathAProc)
-			GetProcAddress(hShell32, "SHGetSpecialFolderPathA");
-		if(SHgsfp)
-		{
-			if(SHgsfp(NULL, appdata, CSIDL_APPDATA, FALSE))
-				appdatadir = appdata;
-			else
-				appdatadir = progfilesdir;
-			if(SHgsfp(NULL, appdata, CSIDL_FAVORITES, FALSE))
-				favoritesdir = appdata;
-			else
-			{
-				if(GetWindowsDirectory(appdata, sizeof(appdata)) == 0)
-					favoritesdir = "";
-				else
-				{
-					strcat(appdata, "\\Favorites");
-					favoritesdir = appdata;
-				}
-			}
-		}
+		if(GetWindowsDirectoryW(widebuf, sizeof(widebuf)) == 0)
+			m_FavoritesDir = "";
 		else
-			appdatadir = progfilesdir;
-
-		FreeLibrary(hShell32);
+			wcscat(widebuf, L"\\Favorites");
 	}
+	m_FavoritesDir.setUtf16((const unsigned short *)widebuf, wcslen(widebuf));
+
+	memset(widebuf, 0, sizeof(widebuf));
+	if(SHGetFolderPathW(NULL, CSIDL_PROGRAM_FILES, NULL, 0, widebuf) != S_OK)
+		m_ProgFilesDir = "C:\\Program Files";
 	else
-		appdatadir = progfilesdir;
+		m_ProgFilesDir.setUtf16((const unsigned short *)widebuf, wcslen(widebuf));
+
+	memset(widebuf, 0, sizeof(widebuf));
+	if(SHGetFolderPathW(NULL, CSIDL_APPDATA, NULL, 0, widebuf) != S_OK)
+		m_AppDataDir = m_ProgFilesDir;
+	else
+		m_AppDataDir.setUtf16((const unsigned short *)widebuf, wcslen(widebuf));
 }
 #endif
 
@@ -629,7 +502,7 @@ void BridgeCfg::InitMemberVars(void) throw(BkException)
 
 void BridgeCfg::readConfig(void) throw(BkException)
 {
-	if(configFileName.empty())
+	if(ConfigFileName.length() < 1)
 		findConfigFile();
 
 	if(!configFileExists)
@@ -647,7 +520,7 @@ void BridgeCfg::readConfig(void) throw(BkException)
 	// parse the file
 
 	ParseXmlDocument(
-		configFileName.c_str(),
+		ConfigFileName,
 		&data,
 		xmlHandlers,
 		xmlStartDocument,
@@ -671,16 +544,16 @@ void BridgeCfg::readConfig(void) throw(BkException)
 
 void BridgeCfg::readBookmarksXbel(BkFolder **root) throw(BkException)
 {
-	if(xbelFileName.empty())
+	if(XbelFileName.length() < 1)
 		findConfigFile();
 	
 	// If the bookmark tree file hasn't been created yet, we'll just
 	// pretend we read it, but exit with an empty tree.
 
-	if(access(xbelFileName.c_str(), 0))
+	if(!QFile::exists(XbelFileName))
 		return;
 
-	ParseXbelDocument(xbelFileName.c_str(), root);
+	ParseXbelDocument(XbelFileName, root);
 }
 
 /***************************************************************************
@@ -698,10 +571,10 @@ void BridgeCfg::readBookmarksXbel(BkFolder **root) throw(BkException)
 
 void BridgeCfg::writeBookmarksXbel(const BkFolder &root) throw(BkException)
 {
-	if(xbelFileName.empty())
+	if(XbelFileName.length() < 1)
 		findConfigFile();
 
-	WriteXbelDocument(xbelFileName.c_str(), root, *this);
+	WriteXbelDocument(XbelFileName, root, *this);
 }
 
 /***************************************************************************
@@ -722,63 +595,67 @@ void BridgeCfg::writeConfig(void) throw(BkException)
 {
 	// locate the existing configuration file (if any)
 	
-	if(configFileName.empty())
+	if(ConfigFileName.length() < 1)
 		findConfigFile();
 
 	// open the file for writing
-	
-	ofstream file(configFileName.c_str(), ios::out|ios::trunc);
-	if(!file)
-	{
-		QString	msg;
 
-		msg.sprintf("Unable to Open Config File \"%s\" for Writing",
-			configFileName.c_str());
-		BKEXCEPT(msg);
-	}
+	QFile	out;
 
-	file << "<bridgecfg version=\"1.0\">" << endl;
+	out.setFileName(ConfigFileName);
+	if(out.open(QIODevice::WriteOnly | QIODevice::Text) == false)
+		BKEXCEPT("Unable to Open Config File for Output");
+
+	QTextStream t(&out);
+	t.setCodec("UTF-8");
+
+	t << "<bridgecfg version=\"1.0\">" << endl;
 
 	// loop through the browsers
 	
+	QString temp;
 	vector<BrowserCfg>::const_iterator it;
 	for(it=browsers.begin(); it!=browsers.end(); ++it)
 	{
-		file << "   <browser>" << endl;
-		if(it->descrip().size())
-			file
+		t << "   <browser>" << endl;
+		EncodeString(it->Descrip(), temp);
+		if(it->Descrip().length())
+			t
 				<< "      "
 				<< "<descrip>"
-				<< EncodeString(it->descrip())
+				<< temp
 				<< "</descrip>"
 				<< endl;
-		file
+		EncodeString(QString(BrowserList[it->browserNum()-1].Name), temp);
+		t
 			<< "      "
 			<< "<name>"
-			<< EncodeString(BrowserList[it->browserNum()-1].Name)
+			<< temp
 			<< "</name>"
 			<< endl;
-		file
+
+		EncodeString(it->Location(), temp);
+		t
 			<< "      "
 			<< "<bookmarks>"
-			<< EncodeString(it->location())
+			<< temp
 			<< "</bookmarks>"
 			<< endl;
-		file
+		t
 			<< "      "
 			<< "<ordinal>"
 			<< it->ordinal()
 			<< "</ordinal>"
 			<< endl;
-		file
+		t
 			<< "      "
 			<< "<browsernum>"
 			<< it->browserNum()
 			<< "</browsernum>"
 			<< endl;
 		if(it->readOnly())
-			file << "      <readonly/>" << endl;
-		file << "   </browser>" << endl;
+			t << "      <readonly/>" << endl;
+		t << "   </browser>" << endl;
 	}
 
 	// loop through the sources
@@ -790,13 +667,13 @@ void BridgeCfg::writeConfig(void) throw(BkException)
 		if(!Any)
 		{
 			Any = 1;
-			file
+			t
 				<< "   "
 				<< "<sources>"
 				<< endl;
 		}
 
-		file
+		t
 			<< "      "
 			<< "<source>"
 			<< *oit
@@ -805,7 +682,7 @@ void BridgeCfg::writeConfig(void) throw(BkException)
 
 	}
 	if(Any)
-		file
+		t
 			<< "   "
 			<< "</sources>"
 			<< endl;
@@ -818,13 +695,13 @@ void BridgeCfg::writeConfig(void) throw(BkException)
 		if(!Any)
 		{
 			Any = 1;
-			file
+			t
 				<< "   "
 				<< "<destinations>"
 				<< endl;
 		}
 
-		file
+		t
 			<< "      "
 			<< "<destination>"
 			<< *oit
@@ -833,12 +710,12 @@ void BridgeCfg::writeConfig(void) throw(BkException)
 
 	}
 	if(Any)
-		file
+		t
 			<< "   "
 			<< "</destinations>"
 			<< endl;
 
-	file << "</bridgecfg>" << endl;
+	t << "</bridgecfg>" << endl;
 }
 
 /***************************************************************************
@@ -944,7 +821,7 @@ static void xmlEndBrowser(void *ctx, const xmlChar *, const xmlChar *, short sta
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_BROWSER);
+	Q_ASSERT(state == SAXSTATE_BROWSER);
 
 	data->browsers->push_back(*(data->browser));
 	delete data->browser;
@@ -973,7 +850,7 @@ static void xmlEndBrowserNum(void *ctx, const xmlChar *, const xmlChar *pChars,
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_BROWSERNUM);
+	Q_ASSERT(state == SAXSTATE_BROWSERNUM);
 
 	if(pChars)
 		data->browser->setBrowserNum(atol((const char *)pChars));
@@ -1001,7 +878,7 @@ static void xmlEndBookmarks(void *ctx, const xmlChar *, const xmlChar *pChars, s
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_BOOKMARKS);
+	Q_ASSERT(state == SAXSTATE_BOOKMARKS);
 
 	if(pChars)
 		data->browser->setLocation(QString::fromUtf8((const char *)pChars));
@@ -1029,7 +906,7 @@ static void xmlEndDescrip(void *ctx, const xmlChar *, const xmlChar *pChars, sho
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_DESCRIP);
+	Q_ASSERT(state == SAXSTATE_DESCRIP);
 
 	if(pChars)
 		data->browser->setDescrip(QString::fromUtf8((const char *)pChars));
@@ -1057,7 +934,7 @@ static void xmlEndDestination(void *ctx, const xmlChar *, const xmlChar *pChars,
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_DESTINATION);
+	Q_ASSERT(state == SAXSTATE_DESTINATION);
 
 	if(prevState==SAXSTATE_DESTINATIONS && pChars)
 		data->destinations->push_back(atoi((const char *)pChars));
@@ -1085,7 +962,7 @@ static void xmlEndName(void *ctx, const xmlChar *, const xmlChar *pChars, short
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_NAME);
+	Q_ASSERT(state == SAXSTATE_NAME);
 
 	if(pChars)
 		data->browser->setBrowser(QString::fromUtf8((const char *)pChars));
@@ -1113,7 +990,7 @@ static void xmlEndOrdinal(void *ctx, const xmlChar *, const xmlChar *pChars, sho
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_ORDINAL);
+	Q_ASSERT(state == SAXSTATE_ORDINAL);
 
 	if(pChars)
 		data->browser->setOrdinal(atoi((const char *)pChars));
@@ -1141,7 +1018,7 @@ static void xmlEndReadonly(void *ctx, const xmlChar *, const xmlChar *, short st
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_READONLY);
+	Q_ASSERT(state == SAXSTATE_READONLY);
 
 	data->browser->setReadOnly(true);
 }
@@ -1168,7 +1045,7 @@ static void xmlEndSource(void *ctx, const xmlChar *, const xmlChar *pChars, shor
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_SOURCE);
+	Q_ASSERT(state == SAXSTATE_SOURCE);
 
 	if(prevState==SAXSTATE_SOURCES && pChars)
 		data->sources->push_back(atoi((const char *)pChars));
