@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Dec 28 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,34 +13,32 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #include "dlgmain.h"
+#include "dlgabout.h"
+#include "dlghelp.h"
 #include "dlgsettings.h"
 #include "dlgaddbrowser.h"
 #include "dlgviewbookmarks.h"
-#include "dlgabout.h"
-#include "dlghelp.h"
 #include "dlgexcept.h"
+
 #include "version.h"
 
 #include "bkutil.h"
 
-#include <qmessagebox.h>
-#include <qlistbox.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
+#include <QMessageBox>
+#include <QFile>
 
 #include <algorithm>
 #include <vector>
@@ -50,17 +48,17 @@ using namespace std;
 
 /***************************************************************************
  *                                                                         *
- *   This class (derived from QListBoxText) represents an item in the      *
+ *   This class (derived from QListWidgetItem) represents an item in the   *
  *   sources or destinations list boxes.  All it really does is act as a   *
  *   container for the ordinal (the browser).                              *
  *                                                                         *
  ***************************************************************************/
 
-class SDItem : public QListBoxText
+class SDItem : public QListWidgetItem
 {
 public:
-	SDItem(QListBox *listbox, const QString & text = QString::null)
-		: QListBoxText(listbox, text), ordinal(0) { };
+	SDItem(const QString &text, QListWidget *listwidget)
+		: QListWidgetItem(text, listwidget), ordinal(0) { };
 
 	BRWSNUM ordinal;
 };
@@ -126,9 +124,6 @@ private:
  *                                                                         *
  *   Parameters:                                                           *
  *      QWidget *parent                                                    *
- *      const char *name                                                   *
- *      bool modal                                                         *
- *      WFlags f                                                           *
  *   Return:                                                               *
  *      None                                                               *
  *   Description:                                                          *
@@ -136,15 +131,17 @@ private:
  *                                                                         *
  ***************************************************************************/
 
-DlgMain::DlgMain( QWidget* parent, const char* name, bool modal, WFlags f )
-	: DlgMainBase( parent, name, modal, f )
+DlgMain::DlgMain(QWidget *parent)
+	: QDialog(parent)
 {
+	setupUi(this);
+
+	m_dlgHelp = NULL;
+
 	QString version;
 
 	version.sprintf("BookmarkBridge %s", BMB_VERSION);
-	setCaption(version);
-
-	m_dlgHelp = NULL;
+	setWindowTitle(version);
 
 	try
 	{
@@ -152,7 +149,7 @@ DlgMain::DlgMain( QWidget* parent, const char* name, bool modal, WFlags f )
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 		return;
@@ -181,7 +178,7 @@ DlgMain::~DlgMain()
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonAboutClicked()                                         *
+ *   DlgMain::on_buttonAbout_clicked()                                     *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -194,16 +191,16 @@ DlgMain::~DlgMain()
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonAboutClicked(void)
+void DlgMain::on_buttonAbout_clicked(void)
 {
-	DlgAbout	dlg(this, NULL, true);
+	DlgAbout dlg(this);
 
 	dlg.exec();
 }
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonAddSourceClicked()                                     *
+ *   DlgMain::on_buttonSourceAdd_clicked()                                *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -217,7 +214,7 @@ void DlgMain::buttonAboutClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonAddSourceClicked(void)
+void DlgMain::on_buttonSourceAdd_clicked(void)
 {
 	// Special case: check to see if the user has not configured ANY browsers
 
@@ -254,9 +251,9 @@ void DlgMain::buttonAddSourceClicked(void)
 
 	// Configure and display the dialog box to add a source browser
 
-	DlgAddBrowser   dlg(browsers, this, NULL, true);
+	DlgAddBrowser   dlg(browsers, this);
 
-	dlg.setCaption("Add Source Browser");
+	dlg.setWindowTitle("Add Source Browser");
 	dlg.labelSelect->setText("Select a Source Browser to Add");
 	if(dlg.exec() != Accepted)
 		return;
@@ -274,7 +271,7 @@ void DlgMain::buttonAddSourceClicked(void)
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 	}
@@ -282,7 +279,7 @@ void DlgMain::buttonAddSourceClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonAddDestinationClicked()                                *
+ *   DlgMain::on_buttonDestAdd_clicked()                                   *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -297,7 +294,7 @@ void DlgMain::buttonAddSourceClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonAddDestinationClicked(void)
+void DlgMain::on_buttonDestAdd_clicked(void)
 {
 	// Special case: check to see if the user has not configured ANY browsers
 
@@ -335,9 +332,9 @@ void DlgMain::buttonAddDestinationClicked(void)
 
 	// Configure and display the dialog box to add a destination browser
 
-	DlgAddBrowser   dlg(browsers, this, NULL, true);
+	DlgAddBrowser   dlg(browsers, this);
 
-	dlg.setCaption("Add Destination Browser");
+	dlg.setWindowTitle("Add Destination Browser");
 	dlg.labelSelect->setText("Select a Destination Browser to Add");
 	if(dlg.exec() != Accepted)
 		return;
@@ -355,7 +352,7 @@ void DlgMain::buttonAddDestinationClicked(void)
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 	}
@@ -363,7 +360,7 @@ void DlgMain::buttonAddDestinationClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonDeleteSourceClicked()                                  *
+ *   DlgMain::on_buttonSourceDelete_clicked()                              *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -377,11 +374,11 @@ void DlgMain::buttonAddDestinationClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonDeleteSourceClicked(void)
+void DlgMain::on_buttonSourceDelete_clicked(void)
 {
 	// make sure a source browser is actually selected
 
-	int nItem = listSources->currentItem();
+	int nItem = listSources->currentRow();
 	if(nItem < 0)
 		return;
 
@@ -413,7 +410,7 @@ void DlgMain::buttonDeleteSourceClicked(void)
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 	}
@@ -421,7 +418,7 @@ void DlgMain::buttonDeleteSourceClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonDeleteDestinationClicked()                             *
+ *   DlgMain::on_buttonDestDelete_clicked()                                *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -435,11 +432,11 @@ void DlgMain::buttonDeleteSourceClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonDeleteDestinationClicked(void)
+void DlgMain::on_buttonDestDelete_clicked(void)
 {
 	// make sure a destination browser is actually selected
 
-	int nItem = listDestinations->currentItem();
+	int nItem = listDestinations->currentRow();
 	if(nItem < 0)
 		return;
 
@@ -471,7 +468,7 @@ void DlgMain::buttonDeleteDestinationClicked(void)
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 	}
@@ -479,7 +476,7 @@ void DlgMain::buttonDeleteDestinationClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonHelpClicked()                                          *
+ *   DlgMain::on_buttonHelp_clicked()                                      *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -491,8 +488,28 @@ void DlgMain::buttonDeleteDestinationClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonHelpClicked(void)
+void DlgMain::on_buttonHelp_clicked(void)
 {
+	// show the dialog and bring it to the front
+
+	QString html_file;
+
+#if defined(Q_WS_X11)
+	html_file.sprintf("%s/bookmarkbridge/index.html", DATADIR);
+#elif defined(Q_WS_WIN)
+	html_file = m_cfg.DataDir + "/index.html";
+#else
+#error "Must define location of index.html"
+#endif
+
+	if(!QFile::exists(html_file))
+	{
+		QMessageBox::information(this, "Notice",
+								 "The BookmarkBridge documentation "
+								 "is not installed");
+		return;
+	}
+
 	// Since the Help dialog is modeless, meaning it doesn't block user
 	// interaction with BookmarkBridge while open, it could already be
 	// open.  If it is not, open it.
@@ -500,17 +517,15 @@ void DlgMain::buttonHelpClicked(void)
 	if(m_dlgHelp == NULL)
 		m_dlgHelp = new DlgHelp(m_cfg);
 
-	// show the dialog and bring it to the front
-
-	m_dlgHelp->setSource("index.html");
+	m_dlgHelp->setSource(html_file);
 	m_dlgHelp->show();
-	m_dlgHelp->setActiveWindow();
+	m_dlgHelp->activateWindow();
 	m_dlgHelp->raise();
 }
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonSettingsClicked()                                      *
+ *   DlgMain::on_buttonSettings_clicked()                                  *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -526,9 +541,9 @@ void DlgMain::buttonHelpClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonSettingsClicked(void)
+void DlgMain::on_buttonSettings_clicked(void)
 {
-	DlgSettings dlg(m_cfg, this, NULL, true);
+	DlgSettings dlg(m_cfg, this);
 
 	// show the dialog then return if the user hit Cancel
 	
@@ -548,7 +563,7 @@ void DlgMain::buttonSettingsClicked(void)
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 		return;
@@ -575,8 +590,8 @@ void DlgMain::buttonSettingsClicked(void)
 
 void DlgMain::refreshButtons(void)
 {
-	buttonSourceDelete->setEnabled(listSources->currentItem() != -1);
-	buttonDestDelete->setEnabled(listDestinations->currentItem() != -1);
+	buttonSourceDelete->setEnabled(listSources->currentRow() != -1);
+	buttonDestDelete->setEnabled(listDestinations->currentRow() != -1);
 	buttonView->setEnabled(m_cfg.sources.size() > 0);
 	buttonMerge->setEnabled(m_cfg.sources.size()>0 && m_cfg.destinations.size()>0);
 }
@@ -616,7 +631,7 @@ void DlgMain::refreshLists(void)
 		fit = std::find(m_cfg.browsers.begin(), m_cfg.browsers.end(), *it);
 		if(fit != m_cfg.browsers.end())
 		{
-			item = new SDItem(listSources, fit->descrip().c_str());
+			item = new SDItem(fit->Descrip(), listSources);
 			item->ordinal = *it;
 		}
 	}
@@ -628,7 +643,7 @@ void DlgMain::refreshLists(void)
 		fit = std::find(m_cfg.browsers.begin(), m_cfg.browsers.end(), *it);
 		if(fit != m_cfg.browsers.end())
 		{
-			item = new SDItem(listDestinations, fit->descrip().c_str());
+			item = new SDItem(fit->Descrip(), listDestinations);
 			item->ordinal = *it;
 		}
 	}
@@ -636,7 +651,7 @@ void DlgMain::refreshLists(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonMergeClicked()                                         *
+ *   DlgMain::on_buttonMerge_clicked()                                     *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -648,7 +663,7 @@ void DlgMain::refreshLists(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonMergeClicked(void)
+void DlgMain::on_buttonMerge_clicked(void)
 {
 	try
 	{
@@ -683,7 +698,7 @@ void DlgMain::buttonMergeClicked(void)
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 		return;
@@ -694,7 +709,7 @@ void DlgMain::buttonMergeClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::buttonViewBookmarksClicked()                                 *
+ *   DlgMain::on_buttonView_clicked()                                      *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -706,7 +721,7 @@ void DlgMain::buttonMergeClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::buttonViewBookmarksClicked(void)
+void DlgMain::on_buttonView_clicked(void)
 {
 	try
 	{
@@ -734,7 +749,7 @@ void DlgMain::buttonViewBookmarksClicked(void)
 		// dialog box also allows the user to tell BookmarkBridge to ignore certain
 		// bookmarks or even an entire folder.
 		
-		DlgViewBookmarks dlg(m_cfg, util.root(), this, NULL, true);
+		DlgViewBookmarks dlg(m_cfg, util.root(), this);
 
 		dlg.exec();
 
@@ -745,7 +760,7 @@ void DlgMain::buttonViewBookmarksClicked(void)
 	}
 	catch(BkException e)
 	{
-		DlgExcept dlg(e, this, NULL, true);
+		DlgExcept dlg(e, this);
 
 		dlg.exec();
 	}
@@ -753,7 +768,7 @@ void DlgMain::buttonViewBookmarksClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::listDestinationsSelectionChanged()                           *
+ *   DlgMain::on_listDestinations_currentRowChanged()                      *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -767,14 +782,14 @@ void DlgMain::buttonViewBookmarksClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::listDestinationsSelectionChanged(void)
+void DlgMain::on_listDestinations_currentRowChanged(void)
 {
 	refreshButtons();
 }
 
 /***************************************************************************
  *                                                                         *
- *   DlgMain::listSourcesSelectionChanged()                                *
+ *   DlgMain::on_listSources_currentRowChanged()                           *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -788,7 +803,7 @@ void DlgMain::listDestinationsSelectionChanged(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgMain::listSourcesSelectionChanged(void)
+void DlgMain::on_listSources_currentRowChanged(void)
 {
 	refreshButtons();
 }
