@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Nov 16 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,37 +13,31 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #include "dlgsettings.h"
-#include "browserlist.h"
 #include "dlgbrowsers.h"
+
+#include "browserlist.h"
 #include "bknode.h"
 #include "bridgecfg.h"
 
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qlistview.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qmessagebox.h>
+#include <QTreeWidget>
+#include <QMessageBox>
 
 extern BROWSERLIST BrowserList[];
 
 #include <vector>
-#include <string>
 #include <algorithm>
 #include <stdlib.h>
 #include <time.h>
@@ -58,10 +52,10 @@ using namespace std;
  *                                                                         *
  ***************************************************************************/
  
-class BrowserCfgItem : public QListViewItem
+class BrowserCfgItem : public QTreeWidgetItem
 {
 public:
-	BrowserCfgItem(QListView *parent) : QListViewItem(parent) { };
+	BrowserCfgItem(QTreeWidget *parent) : QTreeWidgetItem(parent) { };
 
 	std::vector<BrowserCfg>::iterator it;
 };
@@ -73,9 +67,6 @@ public:
  *   Parameters:                                                           *
  *      const BridgeCfg &cfg                                               *
  *      QWidget *parent                                                    *
- *      const char *name                                                   *
- *      bool modal                                                         *
- *      WFlags f                                                           *
  *   Return:                                                               *
  *      None                                                               *
  *   Description:                                                          *
@@ -87,14 +78,15 @@ public:
  *                                                                         *
  ***************************************************************************/
 
-DlgSettings::DlgSettings(
-	const BridgeCfg &cfg,
-	QWidget* parent,
-	const char* name,
-	bool modal,
-	WFlags f)
-	: DlgSettingsBase( parent, name, modal, f ), m_cfg(cfg)
+DlgSettings::DlgSettings(const BridgeCfg &cfg, QWidget* parent)
+	: QDialog( parent ), m_cfg(cfg)
 {
+	QStringList headers;
+
+	setupUi(this);
+
+	headers << "Browser" << "Description";
+	listBrowsers->setHeaderLabels(headers);
 	RefreshList();
 	RefreshButtons();
 }
@@ -132,15 +124,15 @@ DlgSettings::~DlgSettings()
 
 void DlgSettings::RefreshButtons(void)
 {
-	QListViewItem *item = listBrowsers->selectedItem();
+	QList<QTreeWidgetItem *> items = listBrowsers->selectedItems();
 
-	buttonDelete->setEnabled(item != NULL);
-	labelLocation->setEnabled(item != NULL);
-	buttonBrowse->setEnabled(item != NULL);
-	buttonDelete->setEnabled(item != NULL);
-	checkReadonly->setEnabled(item != NULL);
-	labelDesc->setEnabled(item != NULL);
-	editDesc->setEnabled(item != NULL);
+	buttonDelete->setEnabled(items.count() > 0);
+	labelLocation->setEnabled(items.count() > 0);
+	buttonBrowse->setEnabled(items.count() > 0);
+	buttonDelete->setEnabled(items.count() > 0);
+	checkReadonly->setEnabled(items.count() > 0);
+	labelDesc->setEnabled(items.count() > 0);
+	editDesc->setEnabled(items.count() > 0);
 }
 
 /***************************************************************************
@@ -165,15 +157,15 @@ void DlgSettings::RefreshList(void)
 	for(it=m_cfg.browsers.begin(); it!=m_cfg.browsers.end(); ++it)
 	{
 		BrowserCfgItem *item = new BrowserCfgItem(listBrowsers);
-		item->setText(0, it->browser().c_str());
-		item->setText(1, it->descrip().c_str());
+		item->setText(0, it->browser());
+		item->setText(1, it->Descrip());
 		item->it = it;
 	}
 }
 
 /***************************************************************************
  *                                                                         *
- *   DlgSettings::buttonAddClicked()                                       *
+ *   DlgSettings::on_buttonAdd_clicked()                                   *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -188,19 +180,19 @@ void DlgSettings::RefreshList(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgSettings::buttonAddClicked(void)
+void DlgSettings::on_buttonAdd_clicked(void)
 {
-	DlgBrowsers dlg(this, NULL, true);
+	DlgBrowsers dlg(this);
 
 	if(dlg.exec() != QDialog::Accepted)
 		return;
 
 	BrowserCfg cfg;
-	int item = dlg.listBrowsers->currentItem();
-	if(item < 0)
+	QListWidgetItem *item = dlg.listBrowsers->currentItem();
+	if(item == NULL)
 		return;
-	cfg.setBrowser(dlg.listBrowsers->text(item));
-	cfg.setDescrip(dlg.listBrowsers->text(item)+" Bookmarks");
+	cfg.setBrowser(item->text());
+	cfg.setDescrip(item->text()+" Bookmarks");
 	cfg.setBrowserNum(dlg.browser);
 	m_cfg.browsers.push_back(cfg);
 	RefreshList();
@@ -208,7 +200,7 @@ void DlgSettings::buttonAddClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgSettings::listBrowsersSelectionChanged()                           *
+ *   DlgSettings::on_listBrowsers_itemSelectionChanged()                   *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -221,20 +213,26 @@ void DlgSettings::buttonAddClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgSettings::listBrowsersSelectionChanged(void)
+void DlgSettings::on_listBrowsers_itemSelectionChanged(void)
 {
 	RefreshButtons();
 
-	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(listBrowsers->selectedItem());
+	BrowserCfgItem *item;
 
-	editDesc->setText(item==NULL?"":item->it->descrip().c_str());
-	editLocation->setText(item==NULL?"":item->it->location().c_str());
+	QList<QTreeWidgetItem *> items = listBrowsers->selectedItems();
+	if(items.count() != 1)
+		item = NULL;
+	else
+		item = static_cast<BrowserCfgItem *>(items[0]);
+
+	editDesc->setText(item==NULL?"":item->it->Descrip());
+	editLocation->setText(item==NULL?"":item->it->Location());
 	checkReadonly->setChecked(item==NULL?false:item->it->readOnly());
 }
 
 /***************************************************************************
  *                                                                         *
- *   DlgSettings::buttonDeleteClicked()                                    *
+ *   DlgSettings::on_buttonDelete_clicked()                                *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -248,11 +246,15 @@ void DlgSettings::listBrowsersSelectionChanged(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgSettings::buttonDeleteClicked(void)
+void DlgSettings::on_buttonDelete_clicked(void)
 {
 	// make sure a browser is actually selected
+
+	QList<QTreeWidgetItem *> items = listBrowsers->selectedItems();
+	if(items.count() != 1)
+		return;
 	
-	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(listBrowsers->selectedItem());
+	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(items[0]);
 	if(item == NULL)
 		return;
 
@@ -288,10 +290,10 @@ void DlgSettings::buttonDeleteClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgSettings::descripChanged()                                         *
+ *   DlgSettings::on_editDesc_textChanged()                                *
  *                                                                         *
  *   Parameters:                                                           *
- *      None                                                               *
+ *      const QString &                                                    *
  *   Return:                                                               *
  *      None                                                               *
  *   Description:                                                          *
@@ -300,15 +302,17 @@ void DlgSettings::buttonDeleteClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgSettings::descripChanged(const QString &text)
+void DlgSettings::on_editDesc_textChanged(const QString &text)
 {
 	// make sure a browser is actually selected
-	
-	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(listBrowsers->selectedItem());
-	if(item == NULL)
+
+	QList<QTreeWidgetItem *> items = listBrowsers->selectedItems();
+	if(items.count() != 1)
 		return;
 
 	// change the browser configuration to reflect the description change
+
+	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(items[0]);
 	
 	item->it->setDescrip(text);
 	item->setText(1, text);
@@ -316,7 +320,7 @@ void DlgSettings::descripChanged(const QString &text)
 
 /***************************************************************************
  *                                                                         *
- *   DlgSettings::buttonBrowseClicked()                                    *
+ *   DlgSettings::on_buttonBrowse_clicked()                                *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -329,11 +333,15 @@ void DlgSettings::descripChanged(const QString &text)
  *                                                                         *
  ***************************************************************************/
 
-void DlgSettings::buttonBrowseClicked(void)
+void DlgSettings::on_buttonBrowse_clicked(void)
 {
 	// make sure a browser is actually selected
+
+	QList<QTreeWidgetItem *> items = listBrowsers->selectedItems();
+	if(items.count() != 1)
+		return;
 	
-	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(listBrowsers->selectedItem());
+	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(items[0]);
 	if(item == NULL)
 		return;
 
@@ -341,10 +349,10 @@ void DlgSettings::buttonBrowseClicked(void)
 	if(browserbk == NULL)
 		return;
 
-	// tell the browser's class instance to allow the user to browser
+	// tell the browser's class instance to allow the user to browse
 	// for bookmarks.
 	
-	QString bookmarks = item->it->location().c_str();
+	QString bookmarks = item->it->Location();
 	for(;;)
 	{
 		// if the user hit Cancel, forget it
@@ -405,7 +413,7 @@ void DlgSettings::buttonBrowseClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgSettings::checkReadonlyClicked()                                   *
+ *   DlgSettings::on_checkReadonly_clicked()                               *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -417,11 +425,15 @@ void DlgSettings::buttonBrowseClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgSettings::checkReadonlyClicked(void)
+void DlgSettings::on_checkReadonly_clicked(void)
 {
 	// make sure a browser is actually selected
+
+	QList<QTreeWidgetItem *> items = listBrowsers->selectedItems();
+	if(items.count() != 1)
+		return;
 	
-	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(listBrowsers->selectedItem());
+	BrowserCfgItem *item = static_cast<BrowserCfgItem *>(items[0]);
 	if(item == NULL)
 		return;
 
