@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Nov 16 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,49 +13,38 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #include "dlgviewbookmarks.h"
-#include "bkutil.h"
 #include "browserlist.h"
 
-#include <qcheckbox.h>
-#include <qlistview.h>
-#include <qlistbox.h>
-#include <qmessagebox.h>
-#include <qlabel.h>
-#include <vector>
-#include <qpushbutton.h>
-#include <qclipboard.h>
-#include <qapplication.h>
-
-extern BROWSERLIST BrowserList[];
+#include <QMessageBox>
+#include <QClipboard>
 
 /***************************************************************************
  *                                                                         *
- *   The BkListViewItem class (derived from QListViewItem) represents an   *
+ *   The BkListViewItem class (derived from QTreeWidgetItem) represents an *
  *   item in the bookmark tree.  All it really does is hold a pointer to   *
  *   the BkNode representing the folder or bookmark.                       *
  *                                                                         *
  ***************************************************************************/
 
-class BkListViewItem : public QListViewItem
+class BkListViewItem : public QTreeWidgetItem
 {
 public:
-	BkListViewItem(QListView *list) : QListViewItem(list)
+	BkListViewItem(QTreeWidget *list) : QTreeWidgetItem(list)
 		{ m_node = NULL; }
-	BkListViewItem(QListViewItem *item) : QListViewItem(item)
+	BkListViewItem(QTreeWidgetItem *item) : QTreeWidgetItem(item)
 		{ m_node = NULL; }
 
 	BkNode	*m_node;
@@ -66,11 +55,9 @@ public:
  *   DlgViewBookmarks::DlgViewBookmarks()                                  *
  *                                                                         *
  *   Parameters:                                                           *
+ *      const BridgeCfg &                                                  *
  *      BkFolder *root                                                     *
  *      QWidget *parent                                                    *
- *      const char *name                                                   *
- *      bool modal                                                         *
- *      WFlags f                                                           *
  *   Return:                                                               *
  *      None                                                               *
  *   Description:                                                          *
@@ -79,15 +66,15 @@ public:
  *                                                                         *
  ***************************************************************************/
 
-DlgViewBookmarks::DlgViewBookmarks(
-	const BridgeCfg &cfg,
-	BkFolder *root,
-	QWidget *parent,
-	const char *name,
-	bool modal,
-	WFlags f)
-	: DlgViewBookmarksBase(parent, name, modal, f), m_cfg(cfg)
+DlgViewBookmarks::DlgViewBookmarks(const BridgeCfg &cfg,
+								   BkFolder *root,
+								   QWidget *parent)
+	: QDialog(parent), m_cfg(cfg)
 {
+	setupUi(this);
+
+	listBk->setHeaderLabels(QStringList("Bookmarks"));
+
 	fillList(root);
 }
 
@@ -110,7 +97,7 @@ DlgViewBookmarks::~DlgViewBookmarks()
 
 /***************************************************************************
  *                                                                         *
- *   DlgViewBookmarks::buttonCopyClicked()                                 *
+ *   DlgViewBookmarks::on_buttonCopy_clicked()                             *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -122,13 +109,16 @@ DlgViewBookmarks::~DlgViewBookmarks()
  *                                                                         *
  ***************************************************************************/
 
-void DlgViewBookmarks::buttonCopyClicked(void)
+void DlgViewBookmarks::on_buttonCopy_clicked(void)
 {
-	QListViewItem *item = listBk->currentItem();
-	if(item == NULL)
+	BkListViewItem *bk;
+
+	QList<QTreeWidgetItem *> items = listBk->selectedItems();
+	if(items.count() != 1)
 		return;
+	else
+		bk = static_cast<BkListViewItem *>(items[0]);
 
-	BkListViewItem	*bk = static_cast<BkListViewItem *>(item);
 	if(bk->m_node->type() != NODETYPE_BOOKMARK)
 		return;
 
@@ -140,7 +130,7 @@ void DlgViewBookmarks::buttonCopyClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgViewBookmarks::checkIgnoreClicked()                                *
+ *   DlgViewBookmarks::on_checkIgnore_clicked()                            *
  *                                                                         *
  *   Parameters:                                                           *
  *      None                                                               *
@@ -152,19 +142,23 @@ void DlgViewBookmarks::buttonCopyClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgViewBookmarks::checkIgnoreClicked(void)
+void DlgViewBookmarks::on_checkIgnore_clicked(void)
 {
 	bool checked = checkIgnore->isChecked();
 
 	// make sure a bookmark or folder is actually selected
-	
-	QListViewItem *item = listBk->currentItem();
-	if(item == NULL)
-		return;
 
+	BkListViewItem *bk;
+
+	QList<QTreeWidgetItem *> items = listBk->selectedItems();
+
+	if(items.count() != 1)
+		return;
+	else
+		bk = static_cast<BkListViewItem *>(items[0]);
+	
 	// save the user's change
 	
-	BkListViewItem *bk = (BkListViewItem *)item;
 	bk->m_node->setIgnore(checked);
 
 	if(bk->m_node->type() == NODETYPE_FOLDER)
@@ -205,10 +199,10 @@ void DlgViewBookmarks::checkIgnoreClicked(void)
 
 /***************************************************************************
  *                                                                         *
- *   DlgViewBookmarks::listBkSelectionChanged()                            *
+ *   DlgViewBookmarks::on_listBk_itemSelectionChanged()                    *
  *                                                                         *
  *   Parameters:                                                           *
- *      QlistViewItem *item                                                *
+ *      None                                                               *
  *   Return:                                                               *
  *      None                                                               *
  *   Description:                                                          *
@@ -217,7 +211,7 @@ void DlgViewBookmarks::checkIgnoreClicked(void)
  *                                                                         *
  ***************************************************************************/
 
-void DlgViewBookmarks::listBkSelectionChanged(QListViewItem *item)
+void DlgViewBookmarks::on_listBk_itemSelectionChanged(void)
 {
 	BkListViewItem	*bk;
 
@@ -229,7 +223,13 @@ void DlgViewBookmarks::listBkSelectionChanged(QListViewItem *item)
 	listBrowsers->clear();
 	checkIgnore->setChecked(false);
 
-	if(item == NULL)
+	QList<QTreeWidgetItem *> items = listBk->selectedItems();
+	if(items.count() != 1)
+		bk = NULL;
+	else
+		bk = static_cast<BkListViewItem *>(items[0]);
+
+	if(bk == NULL)
 	{
 		// the user didn't click on an item
 		buttonCopy->setEnabled(false);
@@ -242,7 +242,6 @@ void DlgViewBookmarks::listBkSelectionChanged(QListViewItem *item)
 		checkIgnore->setEnabled(true);
 	}
 
-	bk = (BkListViewItem *)item;
 	if(bk->m_node == NULL)
 	{
 		// this item doesn't have an associated node
@@ -267,6 +266,7 @@ void DlgViewBookmarks::listBkSelectionChanged(QListViewItem *item)
 	BrowserOrdLst ordlst = bk->m_node->browserFound();
 	BrowserOrdLst::iterator it;
 	std::vector<BrowserCfg>::const_iterator bit;
+	int i = 0;
 	for(it=ordlst.begin(); it!=ordlst.end(); ++it)
 	{
 		for(bit=m_cfg.browsers.begin(); bit!=m_cfg.browsers.end(); ++bit)
@@ -276,7 +276,7 @@ void DlgViewBookmarks::listBkSelectionChanged(QListViewItem *item)
 		}
 
 		if(bit != m_cfg.browsers.end())
-			listBrowsers->insertItem(bit->descrip().c_str());
+			listBrowsers->insertItem(i++, bit->Descrip());
 	}
 }
 
@@ -375,7 +375,7 @@ void DlgViewBookmarks::fillList(BkFolder *root)
  *                                                                         *
  ***************************************************************************/
 
-void DlgViewBookmarks::fillFolder(BkFolder &parent, QListViewItem *parentItem)
+void DlgViewBookmarks::fillFolder(BkFolder &parent, QTreeWidgetItem *parentItem)
 {
 	BookmarkLst::iterator bit;
 	FolderLst::iterator fit;
@@ -412,8 +412,7 @@ void DlgViewBookmarks::fillFolder(BkFolder &parent, QListViewItem *parentItem)
 
 void DlgViewBookmarks::resizeEvent(QResizeEvent *)
 {
-	QListViewItem *item = listBk->currentItem();
-	listBkSelectionChanged(item);
+	on_listBk_itemSelectionChanged();
 }
 
 /***************************************************************************
