@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Sep 15 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/
 
 /***************************************************************************
@@ -13,26 +13,23 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #include "iexplore.h"
 #include "browserlist.h"
 
-#include <qdir.h>
-#include <qfiledialog.h>
-#include <qfile.h>
-#include <qtextstream.h>
+#include <QFileDialog>
+#include <QTextStream>
 
 #ifdef Q_WS_WIN
 #include <shlobj.h>
@@ -41,7 +38,7 @@
 
 using std::ofstream;
 
-#define WIN32_MAX_PATH		260	// maximum length of filenames in Windows
+#define WIN32_MAX_PATH	   232	// maximum length of filenames in Windows
 
 /***************************************************************************
  *                                                                         *
@@ -90,13 +87,12 @@ BrowserBk *IExplore::classFactory(void)
 static void PurgeDir(const QString &path) throw(BkException)
 {
 	QDir dir(path);
-	QFileInfo	*fi;
-	const QFileInfoList *list = dir.entryInfoList();
-	QFileInfoListIterator it(*list);
+	const QFileInfoList list(dir.entryInfoList());
+	QFileInfoList::const_iterator fi = list.begin();
 
 	// walk through the entries in this directory
 	
-	while((fi = it.current()))
+	while(fi != list.end())
 	{
 		if(fi->isDir())
 		{
@@ -106,7 +102,7 @@ static void PurgeDir(const QString &path) throw(BkException)
 			if( fi->fileName() == "."
 			 || fi->fileName() == "..")
 			{
-				++it;
+				++fi;
 				continue;
 			}
 
@@ -121,9 +117,11 @@ static void PurgeDir(const QString &path) throw(BkException)
 			{
 				QString msg;
 
-				msg.sprintf("Unable to Delete Directory \"%s/%s\"",
-					static_cast<const char *>(path),
-					static_cast<const char *>(fi->fileName()));
+				msg = "Unable to Delete Directory \"";
+				msg += path;
+				msg += "/";
+				msg += fi->fileName();
+				msg += "\"";
 				BKEXCEPT(msg);
 			}
 		}
@@ -131,13 +129,15 @@ static void PurgeDir(const QString &path) throw(BkException)
 		{
 			QString msg;
 
-			msg.sprintf("Unable to Delete Bookmark File \"%s/%s\"",
-				static_cast<const char *>(path),
-				static_cast<const char *>(fi->fileName()));
+			msg = "Unable to Delete Bookmark File \"";
+			msg += path;
+			msg += "/";
+			msg += fi->fileName();
+			msg += "\"";
 			BKEXCEPT(msg);
 		}
 
-		++it;
+		++fi;
 	}
 }
 
@@ -200,8 +200,9 @@ bool IExplore::BrowseForBookmarks(const BridgeCfg &cfg, QString &bookmarks, QWid
 
 	// present a dialog box to the user
 
-	bookmarks = QFileDialog::getExistingDirectory(
-		bookmarks, parent, "Get Favorites", "Select Your Favorites Folder");
+	bookmarks =
+		QFileDialog::getExistingDirectory(parent, "Select Your Favorites "
+										  "Folder", bookmarks);
 
 	return (bookmarks == QString::null);
 }
@@ -209,12 +210,12 @@ bool IExplore::BrowseForBookmarks(const BridgeCfg &cfg, QString &bookmarks, QWid
 bool IExplore::BrowseForBookmarks(const BridgeCfg &, QString &bookmarks, QWidget *parent)
 {
 	if(bookmarks==QString::null || bookmarks=="")
-		bookmarks = QDir::homeDirPath();
+		bookmarks = QDir::homePath();
 
 	// present a dialog box to the user
 
-	bookmarks = QFileDialog::getExistingDirectory(
-		bookmarks, parent, "Get Favorites", "Select Your Favorites Folder");
+	bookmarks = QFileDialog::getExistingDirectory(parent, "Select Your Favorites "
+		"Folder", bookmarks);
 
 	return (bookmarks == QString::null);
 }
@@ -241,24 +242,23 @@ bool IExplore::BrowseForBookmarks(const BridgeCfg &, QString &bookmarks, QWidget
 
 bool IExplore::checkFolderForUrlFiles(const QString &folder, bool recurse/*=false*/)
 {
-	QFileInfo   *fi;
 	QDir        favorites(folder);
 
-	const QFileInfoList *list = favorites.entryInfoList();
-	QFileInfoListIterator it(*list);
+	const QFileInfoList list(favorites.entryInfoList());
+	QFileInfoList::const_iterator fi = list.begin();
 
-	while((fi = it.current()))
+	while(fi != list.end())
 	{
 		if(fi->isDir())
 		{
 			// skip the special directory entries representing
 			// current and parent directory
 
-			if( !strcmp(fi->fileName(), ".")
-			 || !strcmp(fi->fileName(), "..")
+			if( fi->fileName() == "."
+			 || fi->fileName() == ".."
 			 || recurse == false)
 			{
-				++it;
+				++fi;
 				continue;
 			}
 
@@ -266,10 +266,10 @@ bool IExplore::checkFolderForUrlFiles(const QString &folder, bool recurse/*=fals
 				return true;
 		}
 
-		if(fi->fileName().upper().right(4) == ".URL")
+		if(fi->fileName().toUpper().right(4) == ".URL")
 			return true;
 
-		++it;
+		++fi;
 	}
 
 	return false;
@@ -296,8 +296,8 @@ bool IExplore::DetectBrowser(const BridgeCfg &cfg, QStringList &paths)
 {
 	paths.clear();
 
-	if(cfg.favoritesdir.length())
-		paths.append(cfg.favoritesdir.c_str());
+	if(cfg.m_FavoritesDir.length())
+		paths.append(cfg.m_FavoritesDir);
 
 	return true;
 }
@@ -351,22 +351,21 @@ void IExplore::readFolder(const QString &path, BkFolder &folder, BRWSNUM browser
 				throw(BkException)
 {
 	QDir		qdir(path);
-	QFileInfo	*fi;
 
-	const QFileInfoList *list = qdir.entryInfoList();
-	QFileInfoListIterator it(*list);
+	const QFileInfoList list(qdir.entryInfoList());
+	QFileInfoList::const_iterator fi = list.begin();
 
-	while((fi = it.current()))
+	while(fi != list.end())
 	{
 		if(fi->isDir())
 		{
 			// skip the special directory entries representing
 			// current and parent directory
 
-			if(	!strcmp(fi->fileName(), ".")
-			 ||	!strcmp(fi->fileName(), ".."))
+			if(	fi->fileName() == "."
+			 ||	fi->fileName() == "..")
 			{
-				++it;
+				++fi;
 				continue;
 			}
 
@@ -392,9 +391,9 @@ void IExplore::readFolder(const QString &path, BkFolder &folder, BRWSNUM browser
 		{
 			// does this file end in .URL?
 
-			if(strcasecmp(fi->fileName().right(4), ".URL"))
+			if(!fi->fileName().endsWith(".URL", Qt::CaseInsensitive))
 			{
-				++it;
+				++fi;
 				continue;	// skip it
 			}
 
@@ -408,10 +407,10 @@ void IExplore::readFolder(const QString &path, BkFolder &folder, BRWSNUM browser
 			child.setBrowserFound(browserOrd);
 			child.setBrowserSaved(browserOrd);
 
-			readUrlFile(fi, child);
+			readUrlFile(*fi, child);
 		}
 
-		++it;
+		++fi;
 	}
 }
 
@@ -430,15 +429,15 @@ void IExplore::readFolder(const QString &path, BkFolder &folder, BRWSNUM browser
  *                                                                         *
  ***************************************************************************/
 
-void IExplore::readUrlFile(QFileInfo *fi, BkBookmark &bk) throw(BkException)
+void IExplore::readUrlFile(const QFileInfo& fi, BkBookmark &bk) throw(BkException)
 {
 	bool	InternetSection = false;
 	QString	buffer;
 
 	// set the bookmark's title (the filename)
 
-	QString baseName = fi->fileName();
-	if(!strcasecmp((const char *)baseName.right(4), ".URL"))
+	QString baseName = fi.fileName();
+	if(baseName.endsWith(".URL", Qt::CaseInsensitive))
 		baseName = baseName.left(baseName.length()-4);
 	bk.setTitle(baseName);
 	bk.setValidField(BKVALID_TITLE);
@@ -446,19 +445,20 @@ void IExplore::readUrlFile(QFileInfo *fi, BkBookmark &bk) throw(BkException)
 	// open the file
 
 	QFile	fp;
-	fp.setName(fi->filePath());
-	if(fp.open(IO_ReadOnly | IO_Translate) == false)
+	fp.setFileName(fi.filePath());
+	if(fp.open(QIODevice::ReadOnly | QIODevice::Text) == false)
 	{
 		QString msg;
 
-		msg.sprintf("Unable to Open Bookmark File \"%s\"",
-			static_cast<const char *>(fi->filePath()));
+		msg = "Unable to Open Bookmark File \"";
+		msg += fi.filePath();
+		msg += "\"";
 		BKEXCEPT(msg);
 	}
 
 	QTextStream stream(&fp);
 
-	stream.setEncoding(QTextStream::UnicodeUTF8);
+	stream.setCodec("UTF-8");
 
 	// loop through the lines in the file
 
@@ -466,7 +466,7 @@ void IExplore::readUrlFile(QFileInfo *fi, BkBookmark &bk) throw(BkException)
 	{
 		// read one line from the file
 
-		buffer = stream.readLine().stripWhiteSpace();
+		buffer = stream.readLine().simplified();
 
 		// skip blank lines
 
@@ -477,12 +477,13 @@ void IExplore::readUrlFile(QFileInfo *fi, BkBookmark &bk) throw(BkException)
 
 		if(buffer.at(0) == '[')
 		{
-			if(!strcasecmp(buffer, "[InternetShortcut]"))
+			if(buffer.toUpper() == "[INTERNETSHORTCUT]")
 				InternetSection = true;
 			else
 				InternetSection = false;
 		}
-		else if(InternetSection && !strncasecmp(buffer, "URL=", 4))
+		else if(InternetSection &&
+				buffer.startsWith("URL=", Qt::CaseInsensitive))
 		{
 			bk.setUrl(buffer.right(buffer.length()-4));
 			bk.setValidField(BKVALID_URL);
@@ -514,7 +515,6 @@ static void SaveBookmark(const QString & path, const BkBookmark & bookmark) thro
 	filename += "/";
 	filename += bookmark.title();
 	filename += ".url";
-	out.setName(filename);
 
 	if(filename.length() >= WIN32_MAX_PATH)
 	{
@@ -523,17 +523,19 @@ static void SaveBookmark(const QString & path, const BkBookmark & bookmark) thro
 		filename.replace(WIN32_MAX_PATH-4, filename.length()-WIN32_MAX_PATH, "");
 	}
 
-	if(out.open(IO_WriteOnly | IO_Translate) == false)
+	out.setFileName(filename);
+
+	if(out.open(QIODevice::WriteOnly | QIODevice::Text) == false)
 	{
 		QString	msg;
 
-		msg.sprintf("Unable to Open Bookmark File for Writing\n%s",
-			static_cast<const char *>(filename));
+		msg = "Unable to Open Bookmark File for Writing\n";
+		msg += filename;
 		BKEXCEPT(msg);
 	}
 	QTextStream t(&out);
 
-	t.setEncoding(QTextStream::UnicodeUTF8);
+	t.setCodec("UTF-8");
 
 	t
 		<< "[InternetShortcut]"
@@ -601,9 +603,11 @@ void IExplore::saveBookmarksX(
 					{
 						QString msg;
 
-						msg.sprintf("Unable to Delete \"%s/%s\" Folder",
-							static_cast<const char *>(path),
-							static_cast<const char *>(it->m_fit->title()));
+						msg = "Unabe to Delete \"";
+						msg += path;
+						msg += "/";
+						msg += it->m_fit->title();
+						msg += "\"";
 						BKEXCEPT(msg);
 					}
 				}
@@ -626,9 +630,11 @@ void IExplore::saveBookmarksX(
 				{
 					QString msg;
 
-					msg.sprintf("Unable to Create \"%s/%s\" Folder",
-						static_cast<const char *>(path),
-						static_cast<const char *>(it->m_fit->title()));
+					msg = "Unable to Create \"";
+					msg += path;
+					msg += "/";
+					msg += it->m_fit->title();
+					msg += "\"";
 					BKEXCEPT(msg);
 				}
 				it->m_fit->setBrowserFound(browserOrd);
@@ -706,7 +712,7 @@ static void deleteExtraneousUrlFiles(const QString &path, const BkFolder &folder
 	{
 		// figure out the filename without the ending .url
 
-		if(strcasecmp(dir[i].right(4), ".URL"))
+		if(!dir[i].endsWith(".URL", Qt::CaseInsensitive))
 			continue;	// this should never occur because of the filter
 		filename = dir[i].left(dir[i].length()-4);
 
@@ -716,7 +722,7 @@ static void deleteExtraneousUrlFiles(const QString &path, const BkFolder &folder
 				bit != folder.BookmarksEnd();
 				++bit)
 		{
-			if( !strcasecmp(bit->title(), filename)
+			if( bit->title().toUpper() == filename.toUpper()
 			 && !bit->isDeleted())
 				break;	// we have a match, stop searching
 		}
@@ -733,9 +739,11 @@ static void deleteExtraneousUrlFiles(const QString &path, const BkFolder &folder
 		{
 			QString	msg;
 
-			msg.sprintf("Unable to Delete Bookmark File \"%s/%s",
-				static_cast<const char *>(path),
-				static_cast<const char *>(dir[i]));
+			msg = "Unable to Delete Bookmark File \"";
+			msg += path;
+			msg += "/";
+			msg += dir[i];
+			msg += "\"";
 			BKEXCEPT(msg);
 		}
 	}
