@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Aug 24 2003
     copyright            : (C) 2003 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,38 +13,31 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #include <ctype.h>
 #include <stdlib.h>
 #include <stack>
-#include <qfile.h>
-#include <qdir.h>
-#include <qfiledialog.h>
+
+#include <QFile>
+#include <QDir>
+#include <QFileDialog>
 
 #include "konqueror.h"
 #include "browserlist.h"
 #include "xmlparser.h"
 #include "xbelwrite.h"
 
-// for access()
-#ifdef _WIN32
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
 /***************************************************************************
  *                                                                         *
  *   Constants                                                             *
@@ -213,8 +206,8 @@ static bool xmlStartBookmark(void *ctx, const xmlChar *, const xmlChar **atts, s
 		else
 		{
 			data->bookmark->setAttr(
-				(const char *)atts[i],
-				(const char *)atts[i+1],
+				QString::fromUtf8((const char *)atts[i]),
+				QString::fromUtf8((const char *)atts[i+1]),
 				data->browserOrd);
 		}
 	}
@@ -258,18 +251,19 @@ static bool xmlStartFolder(void *ctx, const xmlChar *, const xmlChar **atts, sho
 	
 	// save some attributes in the element
 
-	for(int i=0; atts[i]; i+=2)
-	{
-		if(!xmlStrcmp(atts[i], (const xmlChar *)"folded"))
-			;	// ignore
-		else
+	if(atts)
+		for(int i=0; atts[i]; i+=2)
 		{
-			data->folders->top()->setAttr(
-				(const char *)atts[i],
-				(const char *)atts[i+1],
-				data->browserOrd);
+			if(!xmlStrcmp(atts[i], (const xmlChar *)"folded"))
+				;	// ignore
+			else
+			{
+				data->folders->top()->setAttr(
+					QString::fromUtf8((const char *)atts[i]),
+					QString::fromUtf8((const char *)atts[i+1]),
+					data->browserOrd);
+			}
 		}
-	}
 
 	return false;
 }
@@ -296,8 +290,8 @@ static void xmlEndFolder(void *ctx, const xmlChar *, const xmlChar *, short stat
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_FOLDER);
-	ASSERT(data->folders->size() > 0);
+	Q_ASSERT(state == SAXSTATE_FOLDER);
+	Q_ASSERT(data->folders->size() > 0);
 
 	data->folders->pop();
 }
@@ -324,7 +318,7 @@ static void xmlEndBookmark(void *ctx, const xmlChar *, const xmlChar *, short st
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_BOOKMARK);
+	Q_ASSERT(state == SAXSTATE_BOOKMARK);
 	
 	data->bookmark = NULL;
 }
@@ -355,14 +349,14 @@ static void xmlEndTitle(void *ctx, const xmlChar *, const xmlChar *pChars, short
 	{
 		if(parentState == SAXSTATE_FOLDER)
 		{
-			ASSERT(data->folders->size() > 0);
+			Q_ASSERT(data->folders->size() > 0);
 			data->folders->top()->setTitle(
 				QString::fromUtf8((const char *)pChars));
 			data->folders->top()->setValidField(BKVALID_TITLE);
 		}
 		else if(parentState == SAXSTATE_BOOKMARK)
 		{
-			ASSERT(data->bookmark != NULL);
+			Q_ASSERT(data->bookmark != NULL);
 			data->bookmark->setTitle(
 				QString::fromUtf8((const char *)pChars));
 			data->bookmark->setValidField(BKVALID_TITLE);
@@ -390,15 +384,15 @@ bool Konqueror::AreBookmarksValid(const QString &bookmarks)
 {
 	QFile   file(bookmarks);
 
-	if(file.open(IO_ReadOnly) == false)
+	if(file.open(QIODevice::ReadOnly) == false)
 		return false;
 	QTextStream stream(&file);
 
-	QString line = stream.readLine().stripWhiteSpace();
+	QString line = stream.readLine().simplified();
 	if(!line.startsWith("<!DOCTYPE xbel>"))
 		return false;
 
-	line = stream.readLine().stripWhiteSpace();
+	line = stream.readLine().simplified();
 	return line.startsWith("<xbel folded=\"no\"");
 }
 
@@ -423,16 +417,16 @@ bool Konqueror::BrowseForBookmarks(const BridgeCfg &, QString &bookmarks, QWidge
 	if(bookmarks==QString::null || bookmarks=="")
 	{
 #if defined(Q_WS_X11)
-		bookmarks = QDir::homeDirPath() + "/.kde/share/apps/konqueror";
+		bookmarks = QDir::homePath() + "/.kde/share/apps/konqueror";
 #elif defined(Q_WS_WIN)
-		bookmarks = QDir::homeDirPath();
+		bookmarks = QDir::homePath();
 #else
 #error "Must define default path for Konqueror Bookmarks File"
 #endif
 	}
-	bookmarks = QFileDialog::getOpenFileName(
-		bookmarks, "Bookmark File (bookmarks.xml)",
-		parent, "Get Bookmarks File", "Select Your Bookmarks File");
+	bookmarks =
+		QFileDialog::getOpenFileName(parent, "Select Your Bookmarks File",
+									 bookmarks, "Bookmark File (bookmarks.xml)" );
 
 	return (bookmarks == QString::null);
 }
@@ -481,7 +475,7 @@ bool Konqueror::DetectBrowser(const BridgeCfg &, QStringList &paths)
 	// Start off with the base path.  It would be something like:
 	// /home/ken/.kde/share/apps/konqueror
 
-	basePath = QDir::homeDirPath() + "/.kde/share/apps/konqueror";
+	basePath = QDir::homePath() + "/.kde/share/apps/konqueror";
 
 	// With the base path defined, see if it exists
 
@@ -492,7 +486,7 @@ bool Konqueror::DetectBrowser(const BridgeCfg &, QStringList &paths)
 	QString filename(basePath);
 	filename += "/bookmarks.xml";
 
-	if(access(QDir::convertSeparators(filename), 0) == 0)
+	if(QFile::exists(filename))
 		paths.append(filename);
 	
 	return paths.size() > 0;
@@ -562,14 +556,14 @@ void Konqueror::saveBookmarks(const QString &filename, BkFolder &root, BRWSNUM b
 
 	// open the file for writing
 
-	out.setName(filename);
-	if(out.open(IO_WriteOnly | IO_Translate) == false)
+	out.setFileName(filename);
+	if(out.open(QIODevice::WriteOnly | QIODevice::Text) == false)
 		BKEXCEPT("Unable to Open Konqueror Bookmark File for Output");
 
 	// set up a text stream
 
 	QTextStream t(&out);
-	t.setEncoding(QTextStream::UnicodeUTF8);
+	t.setCodec("UTF-8");
 
 	// write out Konqueror's boilerplate header
 
