@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Oct 05 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/
 
 /***************************************************************************
@@ -13,16 +13,15 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -35,16 +34,12 @@
 #include "browserlist.h"
 #include "xmlparser.h"
 
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qfiledialog.h>
+#include <QFile>
+#include <QFileDialog>
+#include <QDir>
 
-// for access()
 #ifdef _WIN32
-#include <io.h>
 #include <shlobj.h>
-#else
-#include <unistd.h>
 #endif
 
 /***************************************************************************
@@ -224,8 +219,8 @@ static bool htmlStartA(void *ctx, const xmlChar *, const xmlChar **atts, short)
 			}
 			else
 				data->bookmark->setAttr(
-					(const char *)atts[i],
-					(const char *)atts[i+1],
+				QString::fromUtf8((const char *)atts[i]),
+				QString::fromUtf8((const char *)atts[i+1]),
 					data->browserOrd);
 		}
 	}
@@ -281,8 +276,7 @@ static bool htmlStartDL(void *ctx, const xmlChar *, const xmlChar **, short)
 
 	if(data->lastDD != QString::null)
 	{
-		data->folders.top()->setDesc(
-			QString::fromUtf8(data->lastDD).stripWhiteSpace());
+		data->folders.top()->setDesc(data->lastDD.simplified());
 		data->folders.top()->setValidField(BKVALID_DESC);
 		data->lastDD = QString::null;
 	}
@@ -330,8 +324,7 @@ static bool htmlStartDT(void *ctx, const xmlChar *, const xmlChar **, short)
 	if(	data->lastDD != QString::null
 	 &&	data->bookmark != NULL)
 	{
-		data->bookmark->setDesc(
-			QString::fromUtf8(data->lastDD).stripWhiteSpace());
+		data->bookmark->setDesc(data->lastDD.simplified());
 		data->bookmark->setValidField(BKVALID_DESC);
 	}
 	data->lastDD = QString::null;
@@ -361,7 +354,7 @@ static bool htmlStartH3(void *ctx, const xmlChar *, const xmlChar **atts, short)
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(data->folders.size() > 0);
+	Q_ASSERT(data->folders.size() > 0);
 
 	// save some attributes in the element
 
@@ -372,8 +365,8 @@ static bool htmlStartH3(void *ctx, const xmlChar *, const xmlChar **atts, short)
 			BkAttr	attr;
 
 			attr.m_browser = data->browserOrd;
-			attr.m_name = (const char *)atts[i];
-			attr.m_value = (const char *)atts[i+1];
+			attr.m_name = QString::fromUtf8((const char *)atts[i]);
+			attr.m_value = QString::fromUtf8((const char *)atts[i+1]);
 
 			data->attrsH3.push_back(attr);
 		}
@@ -442,7 +435,7 @@ static void htmlEndA(void *ctx, const xmlChar *, const xmlChar *pChars, short, s
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(data->bookmark != NULL);
+	Q_ASSERT(data->bookmark != NULL);
 	if(pChars)
 	{
 		data->bookmark->setTitle(QString::fromUtf8((const char *)pChars));
@@ -475,14 +468,13 @@ static void htmlEndDL(void *ctx, const xmlChar *, const xmlChar *, short, short)
 	if(	data->lastDD != QString::null
 	 &&	data->bookmark != NULL)
 	{
-		data->bookmark->setDesc(
-			QString::fromUtf8(data->lastDD).stripWhiteSpace());
+		data->bookmark->setDesc(data->lastDD.simplified());
 		data->bookmark->setValidField(BKVALID_DESC);
 	}
 	data->bookmark = NULL;
 	data->lastDD = QString::null;
 
-	ASSERT(data->folders.size() > 0);
+	Q_ASSERT(data->folders.size() > 0);
 	data->folders.pop();
 }
 
@@ -508,7 +500,7 @@ static void htmlEndH3(void *ctx, const xmlChar *, const xmlChar *pChars, short,
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(data->folders.size() > 0);
+	Q_ASSERT(data->folders.size() > 0);
 	if(pChars)
 		data->lastH3 = QString::fromUtf8((const char *)pChars);
 	else
@@ -535,7 +527,7 @@ bool Mozilla::AreBookmarksValid(const QString &bookmarks)
 {
 	QFile   file(bookmarks);
 
-	if(file.open(IO_ReadOnly) == false)
+	if(file.open(QIODevice::ReadOnly) == false)
 		return false;
 	QTextStream stream(&file);
 
@@ -563,10 +555,10 @@ bool Mozilla::AreBookmarksValid(const QString &bookmarks)
 bool Mozilla::BrowseForBookmarks(const BridgeCfg &cfg, QString &bookmarks, QWidget *parent)
 {
 	if(bookmarks==QString::null || bookmarks=="")
-		bookmarks.sprintf("%s/Mozilla/Profiles/Default", cfg.appdatadir.c_str());
-	bookmarks = QFileDialog::getOpenFileName(
-		bookmarks, "Bookmark File (bookmarks.html)",
-		parent, "Get Bookmarks File", "Select Your Bookmarks File");
+		bookmarks = cfg.m_AppDataDir + "/Mozilla/Profiles/Default";
+	bookmarks =
+		QFileDialog::getOpenFileName(parent, "Select Your Bookmarks File",
+									 bookmarks, "Bookmark File (bookmarks.html)" );
 
 	return (bookmarks == QString::null);
 }
@@ -574,10 +566,10 @@ bool Mozilla::BrowseForBookmarks(const BridgeCfg &cfg, QString &bookmarks, QWidg
 bool Mozilla::BrowseForBookmarks(const BridgeCfg &, QString &bookmarks, QWidget *parent)
 {
 	if(bookmarks==QString::null || bookmarks=="")
-		bookmarks = QDir::homeDirPath() + "/.mozilla/default";
-	bookmarks = QFileDialog::getOpenFileName(
-		bookmarks, "Bookmark File (bookmarks.html)",
-		parent, "Get Bookmarks File", "Select Your Bookmarks File");
+		bookmarks = QDir::homePath() + "/.mozilla/default";
+	bookmarks = QFileDialog::getOpenFileName(parent,
+		"Select Your Bookmarks File",
+		bookmarks, "Bookmark File (bookmarks.html)");
 
 	return (bookmarks == QString::null);
 }
@@ -631,7 +623,7 @@ bool Mozilla::DetectBrowser(const BridgeCfg &cfg, QStringList &paths)
 	// On Windows it would be something like:
 	// C:\Documents and Settings\Ken\Application Data\Mozilla\default
 
-	basePath.sprintf("%s/Mozilla/Profiles/Default", cfg.appdatadir.c_str());
+	basePath = cfg.m_AppDataDir + "/Mozilla/Profiles/Default";
 
 	// With the base path defined, see if it exists
 
@@ -643,7 +635,7 @@ bool Mozilla::DetectBrowser(const BridgeCfg &cfg, QStringList &paths)
 	// profile directory.  It always ends in ".slt", so we'll just search
 	// for anything matching this pattern.
 
-	QStringList profileList = base.entryList("*.slt", QDir::Dirs);
+	QStringList profileList = base.entryList(QStringList("*.slt"), QDir::Dirs);
 
 	// Did we find any?
 
@@ -681,7 +673,7 @@ bool Mozilla::DetectBrowser(const BridgeCfg &, QStringList &paths)
 	// On Windows it would be something like:
 	// C:\Documents and Settings\Ken\Application Data\Mozilla\default
 
-	basePath = QDir::homeDirPath() + "/.mozilla/default";
+	basePath = QDir::homePath() + "/.mozilla/default";
 
 	// With the base path defined, see if it exists
 
@@ -693,7 +685,7 @@ bool Mozilla::DetectBrowser(const BridgeCfg &, QStringList &paths)
 	// profile directory.  It always ends in ".slt", so we'll just search
 	// for anything matching this pattern.
 
-	QStringList profileList = base.entryList("*.slt", QDir::Dirs);
+	QStringList profileList = base.entryList(QStringList("*.slt"), QDir::Dirs);
 
 	// Did we find any?
 
@@ -746,7 +738,7 @@ static BOOL CALLBACK EnumWndProc(HWND hWnd, LPARAM)
 {
 	char	caption[24];
 
-	if(GetWindowText(hWnd, caption, sizeof(caption)) > 0)
+	if(GetWindowTextA(hWnd, caption, sizeof(caption)) > 0)
 	{
 		if(strnicmp(caption, "mozilla", 7) == 0)
 			MozRunning = true;
@@ -790,8 +782,13 @@ static void charHandler(void *ctx, short state, const xmlChar *ch, int len)
 
 	if(state == SAXSTATE_DD)
 	{
-		for(int i=0; i<len; i++)
-			data->lastDD += ch[i];
+		xmlChar *charData = new xmlChar[len+1];
+		if(charData == NULL)
+			return;
+		memcpy(charData, ch, len);
+		charData[len] = 0;
+		data->lastDD += QString::fromUtf8((const char *)charData);
+		delete [] charData;
 	}
 }
  
@@ -802,7 +799,7 @@ void Mozilla::readBookmarks(const QString &filename, BRWSNUM browserOrd)
 
 	// make sure the file exists before starting
 
-	if(access(filename, 0))
+	if(!QFile::exists(filename))
 		BKEXCEPT("The Mozilla bookmarks could not be found.");
 
 	// parse the file
@@ -818,7 +815,7 @@ void Mozilla::readBookmarks(const QString &filename, BRWSNUM browserOrd)
 		NULL,
 		charHandler);
 
-	ASSERT(data.folders.size() == 0);
+	Q_ASSERT(data.folders.size() == 0);
 }
 
 /***************************************************************************
@@ -845,14 +842,14 @@ void Mozilla::saveBookmarks(const QString &filename, BkFolder &root, BRWSNUM bro
 
 	// open the file for writing
 
-	out.setName(filename);
-	if(out.open(IO_WriteOnly | IO_Translate) == false)
+	out.setFileName(filename);
+	if(out.open(QIODevice::WriteOnly | QIODevice::Text) == false)
 		BKEXCEPT("Unable to Open Mozilla Bookmark File for Output");
 
 	// set up a text stream
 
 	QTextStream t(&out);
-	t.setEncoding(QTextStream::UnicodeUTF8);
+	t.setCodec("UTF-8");
 
 	// write out Mozilla's boilerplate header
 
