@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Feb 18 2003
     copyright            : (C) 2003 by Ken Schenke
-    email                : kenschenke@yahoo.com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,23 +13,22 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
 #include "opera.h"
 
-#include <qfile.h>
-#include <qfiledialog.h>
+#include <QFile>
+#include <QFileDialog>
 
 #ifdef Q_WS_WIN
 #include <windows.h>
@@ -67,7 +66,7 @@ bool Opera::AreBookmarksValid(const QString &bookmarks)
 {
 	QFile file(bookmarks);
 
-	if(file.open(IO_ReadOnly | IO_Translate) == false)
+	if(file.open(QIODevice::ReadOnly | QIODevice::Text) == false)
 		return false;
 
 	QTextStream stream(&file);
@@ -96,10 +95,10 @@ bool Opera::AreBookmarksValid(const QString &bookmarks)
 bool Opera::BrowseForBookmarks(const BridgeCfg &cfg, QString &bookmarks, QWidget *parent)
 {
 	if(bookmarks==QString::null || bookmarks=="")
-		bookmarks.sprintf("%s/Opera", cfg.appdatadir.c_str());
-	bookmarks = QFileDialog::getOpenFileName(
-		bookmarks, "Bookmark File (opera*.adr)",
-		parent, "Get Bookmarks File", "Select Your Bookmarks File");
+		bookmarks = cfg.m_AppDataDir + "/Opera";
+	bookmarks =
+		QFileDialog::getOpenFileName(parent, "Select Your Bookmarks File",
+									 bookmarks, "Bookmark File (opera*.adr)");
 
 	return (bookmarks == QString::null);
 }
@@ -107,10 +106,10 @@ bool Opera::BrowseForBookmarks(const BridgeCfg &cfg, QString &bookmarks, QWidget
 bool Opera::BrowseForBookmarks(const BridgeCfg &, QString &bookmarks, QWidget *parent)
 {
 	if(bookmarks==QString::null || bookmarks=="")
-		bookmarks = QDir::homeDirPath() + "/.opera/default";
-	bookmarks = QFileDialog::getOpenFileName(
-		bookmarks, "Bookmark File (opera*.adr)",
-		parent, "Get Bookmarks File", "Select Your Bookmarks File");
+		bookmarks = QDir::homePath() + "/.opera/default";
+	bookmarks = QFileDialog::getOpenFileName(parent,
+		"Select Your Bookmarks File",
+		bookmarks, "Bookmark File (opera*.adr)");
 
 	return (bookmarks == QString::null);
 }
@@ -152,7 +151,7 @@ BrowserBk *Opera::classFactory(void)
 
 static void CleanUpLine(QString &line)
 {
-	for(uint i=0; i<line.length(); i++)
+	for(int i=0; i<line.length(); i++)
 	{
 		if(!line.at(i).isPrint())
 		{
@@ -191,14 +190,14 @@ bool Opera::DetectBrowser(const BridgeCfg &cfg, QStringList &paths)
 	//   -- or --
 	// C:\Program Files\Opera
 
-	basePath.sprintf("%s/Opera", cfg.appdatadir.c_str());
+	basePath = cfg.m_AppDataDir + "/Opera";
 
 	QString	path;
 
 	if(findBookmarkFile(basePath, path))
 		paths.append(path);
 
-	basePath.sprintf("%s\\Opera", cfg.progfilesdir.c_str());
+	basePath = cfg.m_ProgFilesDir + "\\Opera";
 	if(findBookmarkFile(basePath, path))
 		paths.append(path);
 
@@ -218,7 +217,7 @@ bool Opera::DetectBrowser(const BridgeCfg &, QStringList &paths)
 	//   -- or --
 	// C:\Program Files\Opera
 
-	basePath = QDir::homeDirPath() + "/.opera";
+	basePath = QDir::homePath() + "/.opera";
 
 	QString	path;
 
@@ -249,7 +248,7 @@ bool Opera::DetectBrowser(const BridgeCfg &, QStringList &paths)
  *                                                                         *
  ***************************************************************************/
 
-bool Opera::findBookmarkFile(const char *path, QString &bookmarkFile)
+bool Opera::findBookmarkFile(const QString &path, QString &bookmarkFile)
 {
 	QDir	dir(path, "opera*.adr");
 	QString	subdirPath;
@@ -267,8 +266,8 @@ bool Opera::findBookmarkFile(const char *path, QString &bookmarkFile)
 		{
 			if(subdirs[i]=="." || subdirs[i]=="..")
 				continue;
-			subdirPath.sprintf("%s/%s", path,
-				static_cast<const char *>(subdirs[i]));
+			subdirPath = path + "/";
+			subdirPath += subdirs[i];
 			if(findBookmarkFile(subdirPath, bookmarkFile))
 				return true;
 		}
@@ -285,8 +284,8 @@ bool Opera::findBookmarkFile(const char *path, QString &bookmarkFile)
 
 	// a match was found, go with it
 
-	bookmarkFile.sprintf("%s/%s", path,
-		static_cast<const char *>(dir[0]));
+	bookmarkFile = path + "/";
+	bookmarkFile += dir[0];
 	return true;
 }
 
@@ -322,7 +321,7 @@ void Opera::readAttributes(QTextStream &stream, BkNode &node, QString &line,
 		if(stream.atEnd())
 			break;
 
-		line = stream.readLine().stripWhiteSpace();
+		line = stream.readLine().simplified();
 		if(line.length() < 1)
 			break;
 		
@@ -333,12 +332,12 @@ void Opera::readAttributes(QTextStream &stream, BkNode &node, QString &line,
 		if(line.startsWith("-"))
 			break;		// end of folder
 
-		idx = line.find('=');
+		idx = line.indexOf('=');
 		if(idx < 0)
 			continue;	// not FIELD=VALUE format.  skip this line
 
-		field = line.left(idx).stripWhiteSpace().upper();
-		value = line.right(line.length()-idx-1).stripWhiteSpace();
+		field = line.left(idx).simplified().toUpper();
+		value = line.right(line.length()-idx-1).simplified();
 
 		if(field == "NAME")
 		{
@@ -385,25 +384,27 @@ void Opera::readBookmarks(const QString &path, BRWSNUM browserOrd)
 {
 	QFile file(path);
 
-	if(file.open(IO_ReadOnly | IO_Translate) == false)
+	if(file.open(QIODevice::ReadOnly | QIODevice::Text) == false)
 	{
 		QString msg;
 
-		msg.sprintf("Unable to Read Opera Bookmarks File\n%s", static_cast<const char *>(path));
+		msg = "Unable to Read Opera Bookmarks File\n";
+		msg += path;
 		BKEXCEPT(msg);
 	}
 
 	QTextStream stream(&file);
 	
-	stream.setEncoding(QTextStream::UnicodeUTF8);
+	stream.setCodec("UTF-8");
 
 	QString line = stream.readLine();
 	if(!line.startsWith("Opera Hotlist version 2.0"))
 	{
 		QString msg;
 
-		msg.sprintf("The File %s\nDoes Not Appear to be an Opera Bookmarks File",
-			static_cast<const char *>(path));
+		msg = "The File ";
+		msg += path;
+		msg += "\nDoes Not Appear to be an Opera Bookmarks File";
 		BKEXCEPT(msg);
 	}
 	line = stream.readLine();	// options line. ignore.
@@ -450,7 +451,7 @@ void Opera::readFolder(QTextStream &stream, BkFolder &folder, BRWSNUM browserOrd
 
 		if(needLine)
 		{		
-			line = stream.readLine().stripWhiteSpace();
+			line = stream.readLine().simplified();
 			if(line.length() < 1)
 				continue;	// skip blank lines
 		}
@@ -461,7 +462,7 @@ void Opera::readFolder(QTextStream &stream, BkFolder &folder, BRWSNUM browserOrd
 		//   #URL
 		//   -  (a single dash)
 
-		if(line.upper() == "#FOLDER")
+		if(line.toUpper() == "#FOLDER")
 		{
 			BkFolder childFolder;
 
@@ -471,7 +472,7 @@ void Opera::readFolder(QTextStream &stream, BkFolder &folder, BRWSNUM browserOrd
 			readAttributes(stream, childFolder, line, browserOrd);
 			readFolder(stream, folder.addFolder(childFolder), browserOrd);
 		}
-		else if(line.upper() == "#URL")
+		else if(line.toUpper() == "#URL")
 		{
 			BkBookmark	bmark;
 
@@ -512,15 +513,15 @@ void Opera::saveBookmarks(const QString &filename, BkFolder &root, BRWSNUM brows
 
 	// open the file for writing
 
-	out.setName(filename);
-	if(out.open(IO_WriteOnly | IO_Translate) == false)
+	out.setFileName(filename);
+	if(out.open(QIODevice::WriteOnly | QIODevice::Text) == false)
 		BKEXCEPT("Unable to Open Opera Bookmark File for Output");
 
 	// set up a text stream
 
 	QTextStream t(&out);
 
-	t.setEncoding(QTextStream::UnicodeUTF8);
+	t.setCodec("UTF-8");
 
 	// write out Opera's boilerplate header
 
@@ -585,9 +586,9 @@ static void saveBookmark(QTextStream &t, BkBookmark &bkmark, BRWSNUM browserOrd)
 
 		t
 			<< '\t'
-			<< static_cast<const char *>(name)
+			<< name
 			<< "="
-			<< static_cast<const char *>(value)
+			<< value
 			<< endl;
 	}
 
@@ -660,9 +661,9 @@ static void saveFolder(QTextStream &t, BkFolder &folder, BRWSNUM browserOrd)
 
 				t
 					<< '\t'
-					<< static_cast<const char *>(name)
+					<< name
 					<< "="
-					<< static_cast<const char *>(value)
+					<< value
 					<< endl;
 			}
 
