@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Sep 15 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,16 +13,15 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -221,7 +220,7 @@ static bool xmlStartBookmark(void *ctx, const xmlChar *, const xmlChar **atts, s
 	{
 		if(!xmlStrcmp(atts[i], (const xmlChar *)"href"))
 		{
-			data->bookmark->setUrl((const char *)atts[i+1]);
+			data->bookmark->setUrl(QString::fromUtf8((const char *)atts[i+1]));
 			data->bookmark->setValidField(BKVALID_URL);
 		}
 	}
@@ -315,7 +314,7 @@ static bool xmlStartMetadata(void *, const xmlChar *, const xmlChar **atts, shor
 
 static void xmlEndBrowser(void *ctx, const xmlChar *, const xmlChar *pChars, short state, short)
 {
-	ASSERT(state == SAXSTATE_BROWSER);
+	Q_ASSERT(state == SAXSTATE_BROWSER);
 
 	SAXDATA	*data = (SAXDATA *)ctx;
 	BkNode	*pNode;
@@ -324,7 +323,7 @@ static void xmlEndBrowser(void *ctx, const xmlChar *, const xmlChar *pChars, sho
 		pNode = data->bookmark;
 	else
 		pNode = data->folders->top();
-	ASSERT(pNode != NULL);
+	Q_ASSERT(pNode != NULL);
 
 	pNode->setBrowserSaved(atol((const char *)pChars));
 }
@@ -351,8 +350,8 @@ static void xmlEndFolder(void *ctx, const xmlChar *, const xmlChar *, short stat
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_FOLDER);
-	ASSERT(data->folders->size() > 0);
+	Q_ASSERT(state == SAXSTATE_FOLDER);
+	Q_ASSERT(data->folders->size() > 0);
 
 	data->folders->pop();
 }
@@ -379,7 +378,7 @@ static void xmlEndBookmark(void *ctx, const xmlChar *, const xmlChar *, short st
 {
 	SAXDATA *data = (SAXDATA *)ctx;
 
-	ASSERT(state == SAXSTATE_BOOKMARK);
+	Q_ASSERT(state == SAXSTATE_BOOKMARK);
 
 	data->bookmark = NULL;
 }
@@ -404,7 +403,7 @@ static void xmlEndBookmark(void *ctx, const xmlChar *, const xmlChar *, short st
 
 static void xmlEndIgnore(void *ctx, const xmlChar *, const xmlChar *, short state, short)
 {
-	ASSERT(state == SAXSTATE_IGNORE);
+	Q_ASSERT(state == SAXSTATE_IGNORE);
 
 	SAXDATA	*data = (SAXDATA *)ctx;
 	BkNode	*pNode;
@@ -413,7 +412,7 @@ static void xmlEndIgnore(void *ctx, const xmlChar *, const xmlChar *, short stat
 		pNode = data->bookmark;
 	else
 		pNode = data->folders->top();
-	ASSERT(pNode != NULL);
+	Q_ASSERT(pNode != NULL);
 
 	pNode->setIgnore(true);
 }
@@ -444,14 +443,14 @@ static void xmlEndTitle(void *ctx, const xmlChar *, const xmlChar *pChars, short
 	{
 		if(parentState == SAXSTATE_FOLDER)
 		{
-			ASSERT(data->folders->size() > 0);
+			Q_ASSERT(data->folders->size() > 0);
 			data->folders->top()->setTitle(
 				QString::fromUtf8((const char *)pChars));
 			data->folders->top()->setValidField(BKVALID_TITLE);
 		}
 		else if(parentState == SAXSTATE_BOOKMARK)
 		{
-			ASSERT(data->bookmark != NULL);
+			Q_ASSERT(data->bookmark != NULL);
 			data->bookmark->setTitle(
 				QString::fromUtf8((const char *)pChars));
 			data->bookmark->setValidField(BKVALID_TITLE);
@@ -485,14 +484,14 @@ static void xmlEndDesc(void *ctx, const xmlChar *, const xmlChar *pChars, short,
 	{
 		if(parentState == SAXSTATE_FOLDER)
 		{
-			ASSERT(data->folders->size() > 0);
+			Q_ASSERT(data->folders->size() > 0);
 			data->folders->top()->setDesc(
 				QString::fromUtf8((const char *)pChars));
 			data->folders->top()->setValidField(BKVALID_DESC);
 		}
 		else if(parentState == SAXSTATE_BOOKMARK)
 		{
-			ASSERT(data->bookmark != NULL);
+			Q_ASSERT(data->bookmark != NULL);
 			data->bookmark->setDesc(
 				QString::fromUtf8((const char *)pChars));
 			data->bookmark->setValidField(BKVALID_DESC);
@@ -518,7 +517,7 @@ static void xmlEndDesc(void *ctx, const xmlChar *, const xmlChar *pChars, short,
  *                                                                         *
  ***************************************************************************/
 
-void ParseXbelDocument(const char *filename, BkFolder **root) throw(BkException)
+void ParseXbelDocument(const QString &filename, BkFolder **root) throw(BkException)
 {
 	SAXDATA		data;
 
