@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Sep 21 2002
     copyright            : (C) 2002 by Ken Schenke
-    email                : kenschenke at yahoo dot com
+    email                : kschenke at users dot sourceforge dot net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,16 +13,15 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   In addition, as a special exception, Ken Schenke gives permission to  *
- *   link the code of this program with the Qt non-commercial edition (or  *
- *   with modified versions of the Qt non-commercial edition that use the  *
- *   same license as the Qt non-commercial edition, and distribute linked  *
- *   combinations including the two.  You must obey the GNU General Public *
- *   License in all respects for all of the code used other than the Qt    *
- *   Non-Commercial edition.  If you modify this file, you may extend this *
- *   exception to your version of the file, but you are not obligated to   *
- *   do so.  If you do not wish to do so, delete this exception statement  *
- *   from your version.                                                    *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the Free Software           *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  *                                                                         *
  ***************************************************************************/
 
@@ -32,13 +31,9 @@
 #include <stdarg.h>
 
 #include <ctype.h>
-#ifdef _WIN32
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
 
-#include <qstring.h>
+#include <QFile>
+#include <QDir>
 
 /***************************************************************************
  *                                                                         *
@@ -130,7 +125,7 @@ static void GlobalReplace(QString &str, const char *s1, const char *subs)
 	int i = 0;
 	for(;;)
 	{
-		i = str.find(s1, i);
+		i = str.indexOf(s1, i);
 		if(i < 0)
 			break;
 		str.replace(i, strlen(s1), subs);
@@ -165,7 +160,7 @@ static void GlobalReplace(QString &str, const char *s1, const char *subs)
  ***************************************************************************/
 
 void ParseHtmlDocument(
-	const char *filename,
+	const QString &filename,
 	void *ctx,
 	ELEMHANDLER *elems,
 	BEGIN_DOC_HANDLER funcBegin,
@@ -200,18 +195,36 @@ void ParseHtmlDocument(
 
 	// make sure the file exists before starting
 
-	if(access(filename, 0))
+	if(!QFile::exists(filename))
 		BKEXCEPT("HTML File Not Found");
 
+	// Read the file into memory
+
+	QFileInfo fi(filename);
+	uint file_size = fi.size();
+	xmlChar *buffer = new xmlChar[file_size+1];
+	if(buffer == 0)
+		BKEXCEPT("Unable to Allocate Memory");
+	memset(buffer, 0, file_size+1);
+	QFile file(filename);
+	if(file.open(QIODevice::ReadOnly) == false)
+		BKEXCEPT("Unable to Read HTML File");
+	QByteArray bytes = file.readAll();
+	memcpy(buffer, bytes.data(), file_size);
+
 	// parse the file
 
-	if(htmlSAXParseFile(
-		filename,
+	if(htmlSAXParseDoc(
+		buffer,
 		NULL,		// encoding
 		&saxhandler,
 		&data))
 		BKEXCEPT("Failed to Parse HTML File");
 
+	// delete the memory buffer
+
+	delete [] buffer;
+
 	// verify the results of the parse
 
 	if(	data.state->size() != 1
@@ -251,7 +264,7 @@ void ParseHtmlDocument(
  ***************************************************************************/
 
 void ParseXmlDocument(
-	const char *filename,
+	const QString &filename,
 	void *ctx,
 	ELEMHANDLER *elems,
 	BEGIN_DOC_HANDLER funcBegin,
@@ -287,27 +300,42 @@ void ParseXmlDocument(
 
 	// make sure the file exists before starting
 
-	if(access(filename, 0))
-	{
-		QString msg;
+	if(!QFile::exists(filename))
+		BKEXCEPT("Xml Document Does Not Exist");
 
-		msg.sprintf("Xml Document \"%s\" Does Not Exist", filename);
-		BKEXCEPT(msg);
-	}
+	// Read the file into memory
+
+	QFileInfo fi(filename);
+	uint file_size = fi.size();
+	char *buffer = new char[file_size+1];
+	if(buffer == 0)
+		BKEXCEPT("Unable to Allocate Memory");
+	memset(buffer, 0, file_size+1);
+	QFile file(filename);
+	if(file.open(QIODevice::ReadOnly) == false)
+		BKEXCEPT("Unable to Read Xml Document");
+
+	QByteArray bytes = file.readAll();
+	memcpy(buffer, bytes.data(), file_size);
 
 	// parse the file
 
-	if(xmlSAXUserParseFile(
+	if(xmlSAXUserParseMemory(
 		&saxhandler,
 		&data,
-		filename))
+		buffer,
+		file_size))
 	{
 		QString	msg;
 
-		msg.sprintf("XML Parser Failed on file \"%s\"", filename);
+		msg = "XML Parser Failed on file \"" + filename + "\"";
 		BKEXCEPT(msg);
 	}
 
+	// delete the memory buffer
+
+	delete [] buffer;
+
 	// verify the results of the parse
 
 	if(	data.state->size() != 1
